{
 "cells": [
  {
   "cell_type": "markdown",
   "source": [
    "# LnZ comparison"
   ],
   "metadata": {
    "collapsed": false
   }
  },
  {
   "cell_type": "code",
   "execution_count": 117,
   "outputs": [],
   "source": [
    "import bilby\n",
    "from funnel.fi_core import get_fi_lnz_list\n",
    "import numpy as np\n",
    "import pandas as pd\n",
    "\n",
    "np.random.seed(42)\n",
    "\n",
    "\n",
    "class LartillotLikelihood(bilby.Likelihood):\n",
    "    def __init__(self, dim, v):\n",
    "        self.dim = dim\n",
    "        self.v = v\n",
    "        super().__init__(parameters={f\"x{i}\": None for i in range(dim)})\n",
    "\n",
    "    def log_likelihood(self):\n",
    "        x = np.array(list(self.parameters.values()))\n",
    "        lnl = -np.power(x, 2) / (2 * self.v)\n",
    "        if self.dim == 1:\n",
    "            return lnl[0]\n",
    "        else:\n",
    "            return np.sum(lnl)\n",
    "\n",
    "\n",
    "def get_prior(n_dim):\n",
    "    pri = bilby.core.prior.PriorDict()\n",
    "    for i in range(n_dim):\n",
    "        pri[f'x{i}'] = bilby.core.prior.TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000)\n",
    "    return pri\n",
    "\n",
    "\n",
    "def true_lnz(v, dim):\n",
    "    return (dim / 2) * (np.log(v) - np.log(1 + v))\n",
    "\n",
    "\n",
    "def nested_sampling_lnz(v, dim):\n",
    "    likelihood = LartillotLikelihood(dim, v)\n",
    "    priors = get_prior(dim)\n",
    "    result = bilby.run_sampler(\n",
    "        likelihood=likelihood,\n",
    "        priors=priors,\n",
    "        sampler=\"dynesty\",\n",
    "        nlive=1000,\n",
    "        label=f\"lartillot_dynesty_d{dim}_v{v}\",\n",
    "        clean=False,\n",
    "        sample='rwalk'\n",
    "    )\n",
    "    return (result.log_evidence, result.log_evidence_err)\n",
    "\n",
    "\n",
    "def parallel_tempering_lnz(v, dim):\n",
    "    likelihood = LartillotLikelihood(dim, v)\n",
    "    priors = get_prior(dim)\n",
    "    result = bilby.run_sampler(\n",
    "        likelihood=likelihood,\n",
    "        priors=priors,\n",
    "        sampler=\"bilby_mcmc\",\n",
    "        ntemps=10,\n",
    "        label=f\"lartillot_ptmc_d{dim}_v{v}\",\n",
    "        clean=False,\n",
    "        proposal_cycle='default',\n",
    "        printdt=10,\n",
    "        nsamples=2000,\n",
    "    )\n",
    "    return (result.log_evidence, result.log_evidence_err)\n",
    "\n",
    "\n",
    "def __simulate_posterior(v, dim, nsamp=1000):\n",
    "    likelihood = LartillotLikelihood(dim, v)\n",
    "    priors = get_prior(dim)\n",
    "    post = []\n",
    "    scale = np.sqrt(v / (v + 1))\n",
    "    for i in range(nsamp):\n",
    "        params = {f'x{i}': np.random.normal(scale=scale) for i in range(dim)}\n",
    "        likelihood.parameters.update(params)\n",
    "        post.append(dict(\n",
    "            log_likelihood=likelihood.log_likelihood(),\n",
    "            log_prior=priors.ln_prob(likelihood.parameters),\n",
    "            **params\n",
    "        ))\n",
    "    return pd.DataFrame(post)\n",
    "\n",
    "\n",
    "def fi_lnz(v, dim, nsamp=1000):\n",
    "    lnzs, r_vals, samp = get_fi_lnz_list(\n",
    "        __simulate_posterior(v, dim, nsamp=nsamp),\n",
    "        r_vals=np.linspace(0.1, 100, 100),\n",
    "        num_ref_params=1,\n",
    "        weight_samples_by_lnl=True\n",
    "    )\n",
    "    # only keep last 90% of lnzs\n",
    "    lnzs = lnzs[:, -int(0.9 * nsamp):]\n",
    "    return np.median(lnzs), np.std(lnzs)\n",
    "\n",
    "\n",
    "def print_result_dict(results, dim, v):\n",
    "    print(f\"Lartillot {dim}D (v={v:0.2f})\")\n",
    "    print(\"----------------------------\")\n",
    "    for k, res in results.items():\n",
    "        if isinstance(res, tuple):\n",
    "            res = f\"{res[0]:0.2f} +/- {res[1]:0.2f}\"\n",
    "        else:\n",
    "            res = f\"{res:0.2f}\"\n",
    "        print(f\"{k}: {res}\")"
   ],
   "metadata": {
    "collapsed": false
   }
  },
  {
   "cell_type": "markdown",
   "source": [
    "## 1D Case"
   ],
   "metadata": {
    "collapsed": false
   },
   "execution_count": 105
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "outputs": [],
   "source": [
    "v, dim = 0.01, 1\n",
    "results_1d = dict()\n",
    "results_1d[\"True\"] = true_lnz(v, dim)\n",
    "results_1d[\"Nested Sampling\"] = nested_sampling_lnz(v, dim)\n",
    "results_1d[\"Parallel Tempering\"] = parallel_tempering_lnz(v, dim)\n",
    "results_1d[\"FI\"] = fi_lnz(v, dim)"
   ],
   "metadata": {
    "collapsed": false
   }
  },
  {
   "cell_type": "code",
   "execution_count": 109,
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Lartillot 1D (v=0.01)\n",
      "----------------------------\n",
      "True: -2.31\n",
      "Nested Sampling: -2.29 +/- 0.06\n",
      "Parallel Tempering: -2.24 +/- 0.02\n",
      "FI: -2.30 +/- 0.60\n"
     ]
    }
   ],
   "source": [
    "print_result_dict(results_1d, dim, v)"
   ],
   "metadata": {
    "collapsed": false
   }
  },
  {
   "cell_type": "markdown",
   "source": [
    "## 20D Case"
   ],
   "metadata": {
    "collapsed": false
   }
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "20:52 bilby INFO    : Running for label 'lartillot_dynesty_d20_v0.01', output will be saved to 'outdir'\n",
      "/home/avaj040/.cache/pypoetry/virtualenvs/funnel-ZrW66eTN-py3.8/lib/python3.8/site-packages/bilby/core/utils/log.py:73: DeprecationWarning: Accessing attr.__version__ is deprecated and will be removed in a future release. Use importlib.metadata directly to query for attrs's packaging metadata.\n",
      "  vdict[key] = str(getattr(sys.modules[key], \"__version__\", \"N/A\"))\n",
      "20:52 bilby INFO    : Analysis priors:\n",
      "20:52 bilby INFO    : x0=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:52 bilby INFO    : x1=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:52 bilby INFO    : x2=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:52 bilby INFO    : x3=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:52 bilby INFO    : x4=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:52 bilby INFO    : x5=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:52 bilby INFO    : x6=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:52 bilby INFO    : x7=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:52 bilby INFO    : x8=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:52 bilby INFO    : x9=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:52 bilby INFO    : x10=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:52 bilby INFO    : x11=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:52 bilby INFO    : x12=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:52 bilby INFO    : x13=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:52 bilby INFO    : x14=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:52 bilby INFO    : x15=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:52 bilby INFO    : x16=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:52 bilby INFO    : x17=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:52 bilby INFO    : x18=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:52 bilby INFO    : x19=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:52 bilby INFO    : Analysis likelihood class: <class '__main__.LartillotLikelihood'>\n",
      "20:52 bilby INFO    : Analysis likelihood noise evidence: nan\n",
      "20:52 bilby INFO    : Single likelihood evaluation took 1.886e-04 s\n",
      "20:52 bilby INFO    : Using sampler Dynesty with kwargs {'nlive': 1000, 'bound': 'live', 'sample': 'rwalk', 'periodic': None, 'reflective': None, 'update_interval': 600, 'first_update': None, 'npdim': None, 'rstate': None, 'queue_size': 1, 'pool': None, 'use_pool': None, 'live_points': None, 'logl_args': None, 'logl_kwargs': None, 'ptform_args': None, 'ptform_kwargs': None, 'gradient': None, 'grad_args': None, 'grad_kwargs': None, 'compute_jac': False, 'enlarge': None, 'bootstrap': None, 'walks': 100, 'facc': 0.2, 'slices': None, 'fmove': 0.9, 'max_move': 100, 'update_func': None, 'ncdim': None, 'blob': False, 'save_history': False, 'history_filename': None, 'maxiter': None, 'maxcall': None, 'dlogz': 0.1, 'logl_max': inf, 'n_effective': None, 'add_live': True, 'print_progress': True, 'print_func': <bound method Dynesty._print_func of <bilby.core.sampler.dynesty.Dynesty object at 0x7f9d97721f10>>, 'save_bounds': False, 'checkpoint_file': None, 'checkpoint_every': 60, 'resume': False}\n",
      "20:52 bilby INFO    : Checkpoint every check_point_delta_t = 600s\n",
      "20:52 bilby INFO    : Using dynesty version 2.1.2\n",
      "20:52 bilby INFO    : Using the bilby-implemented rwalk sample method with ACT estimated walks. An average of 4 steps will be accepted up to chain length 5000.\n",
      "20:52 bilby INFO    : Generating initial points from the prior\n"
     ]
    },
    {
     "data": {
      "text/plain": "1it [00:00, ?it/s]",
      "application/vnd.jupyter.widget-view+json": {
       "version_major": 2,
       "version_minor": 0,
       "model_id": "16c659fd6e6e4097b9a17b384eaf1b1d"
      }
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "20:55 bilby INFO    : Written checkpoint file outdir/lartillot_dynesty_d20_v0.01_resume.pickle\n",
      "20:55 bilby INFO    : Rejection sampling nested samples to obtain 7823 posterior samples\n",
      "20:55 bilby INFO    : Sampling time: 0:02:59.191276\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "20:55 bilby INFO    : Summary of results:\n",
      "nsamples: 7823\n",
      "ln_noise_evidence:    nan\n",
      "ln_evidence: -45.256 +/-  0.223\n",
      "ln_bayes_factor:    nan +/-  0.223\n",
      "\n",
      "20:55 bilby INFO    : Running for label 'lartillot_ptmc_d20_v0.01', output will be saved to 'outdir'\n",
      "/home/avaj040/.cache/pypoetry/virtualenvs/funnel-ZrW66eTN-py3.8/lib/python3.8/site-packages/bilby/core/utils/log.py:73: DeprecationWarning: Accessing attr.__version__ is deprecated and will be removed in a future release. Use importlib.metadata directly to query for attrs's packaging metadata.\n",
      "  vdict[key] = str(getattr(sys.modules[key], \"__version__\", \"N/A\"))\n",
      "20:55 bilby INFO    : Analysis priors:\n",
      "20:55 bilby INFO    : x0=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:55 bilby INFO    : x1=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:55 bilby INFO    : x2=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:55 bilby INFO    : x3=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:55 bilby INFO    : x4=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:55 bilby INFO    : x5=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:55 bilby INFO    : x6=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:55 bilby INFO    : x7=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:55 bilby INFO    : x8=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:55 bilby INFO    : x9=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:55 bilby INFO    : x10=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:55 bilby INFO    : x11=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:55 bilby INFO    : x12=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:55 bilby INFO    : x13=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:55 bilby INFO    : x14=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:55 bilby INFO    : x15=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:55 bilby INFO    : x16=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:55 bilby INFO    : x17=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:55 bilby INFO    : x18=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:55 bilby INFO    : x19=TruncatedNormal(mu=0, sigma=1, minimum=-1000, maximum=1000, name=None, latex_label=None, unit=None, boundary=None)\n",
      "20:55 bilby INFO    : Analysis likelihood class: <class '__main__.LartillotLikelihood'>\n",
      "20:55 bilby INFO    : Analysis likelihood noise evidence: nan\n",
      "20:55 bilby INFO    : Single likelihood evaluation took 1.657e-04 s\n",
      "20:55 bilby INFO    : Using sampler Bilby_MCMC with kwargs {'nsamples': 2000, 'nensemble': 1, 'pt_ensemble': False, 'ntemps': 10, 'Tmax': None, 'Tmax_from_SNR': 20, 'initial_betas': None, 'adapt': True, 'adapt_t0': 100, 'adapt_nu': 10, 'pt_rejection_sample': False, 'burn_in_nact': 10, 'thin_by_nact': 1, 'fixed_discard': 0, 'autocorr_c': 5, 'L1steps': 100, 'L2steps': 3, 'printdt': 10, 'check_point_delta_t': 1800, 'min_tau': 1, 'proposal_cycle': 'default', 'stop_after_convergence': False, 'fixed_tau': None, 'tau_window': None, 'evidence_method': 'stepping_stone', 'initial_sample_method': 'prior', 'initial_sample_dict': None}\n",
      "20:55 bilby INFO    : Initializing BilbyPTMCMCSampler with:\n",
      "  Convergence settings: ConvergenceInputs(autocorr_c=5, burn_in_nact=10, thin_by_nact=1, fixed_discard=0, target_nsamples=2000, stop_after_convergence=False, L1steps=100, L2steps=3, min_tau=1, fixed_tau=None, tau_window=None)\n",
      "  Parallel-tempering settings: ParallelTemperingInputs(ntemps=10, nensemble=1, Tmax=None, Tmax_from_SNR=20, initial_betas=None, adapt=True, adapt_t0=100, adapt_nu=10, pt_ensemble=False)\n",
      "  proposal_cycle: default\n",
      "  pt_rejection_sample: False\n",
      "20:55 bilby INFO    : Setting parallel tempering inputs=ParallelTemperingInputs(ntemps=10, nensemble=1, Tmax=None, Tmax_from_SNR=20, initial_betas=None, adapt=True, adapt_t0=100, adapt_nu=10, pt_ensemble=False)\n",
      "20:55 bilby INFO    : Initializing BilbyPTMCMCSampler with:ntemps=10, nensemble=1, pt_ensemble=False, initial_betas=[1.         0.71687116 0.51390427 0.36840315 0.2640976  0.18932395\n",
      " 0.13572088 0.09729439 0.06974754 0.05      ], initial_sample_method=prior, initial_sample_dict=None\n",
      "\n",
      "20:55 bilby INFO    : Using initial sample {'x0': -0.2795374292990265, 'x1': -0.1717320863039971, 'x2': 0.05968361770550555, 'x3': -0.5230902286641548, 'x4': -1.6633760314925232, 'x5': -0.21294322516342162, 'x6': -0.585494068660412, 'x7': -0.8095976482225977, 'x8': 0.9182833389630245, 'x9': -0.47189605378706473, 'x10': -0.4904898766971261, 'x11': 1.4137114591843285, 'x12': 0.3125255400114014, 'x13': -0.3159452862583118, 'x14': 0.3666388720970858, 'x15': 0.407628354348433, 'x16': -0.8250533346649914, 'x17': 0.79153659896676, 'x18': -1.693913217753955, 'x19': -1.0375215193741993}\n",
      "20:55 bilby INFO    : Using ProposalCycle:\n",
      "  AdaptiveGaussianProposal(acceptance_ratio:nan,n:0,scale:1,)\n",
      "  DifferentialEvolutionProposal(acceptance_ratio:nan,n:0,)\n",
      "  UniformProposal(acceptance_ratio:nan,n:0,)\n",
      "  KDEProposal(acceptance_ratio:nan,n:0,trained:0,)\n",
      "  FisherMatrixProposal(acceptance_ratio:nan,n:0,scale:1,)\n",
      "  GMMProposal(acceptance_ratio:nan,n:0,trained:0,)\n",
      "\n",
      "20:55 bilby INFO    : Setting convergence_inputs=ConvergenceInputs(autocorr_c=5, burn_in_nact=10, thin_by_nact=1, fixed_discard=0, target_nsamples=2000, stop_after_convergence=False, L1steps=100, L2steps=3, min_tau=1, fixed_tau=None, tau_window=None)\n",
      "20:55 bilby INFO    : Drawing 2000 samples\n",
      "20:55 bilby INFO    : Checkpoint every check_point_delta_t=1800s\n",
      "20:55 bilby INFO    : Print update every printdt=10s\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.80e+01|0:00:10|4.60e+01(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.10ms/ev|maxl=-662.57|ETF=-\n",
      "9.50e+01|0:00:20|9.40e+01(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.15ms/ev|maxl=-662.57|ETF=-\n",
      "1.39e+02|0:00:30|1.39e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.28ms/ev|maxl=-662.57|ETF=-\n",
      "1.85e+02|0:00:40|1.84e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.21ms/ev|maxl=-662.57|ETF=-\n",
      "2.31e+02|0:00:50|2.29e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.18ms/ev|maxl=-662.57|ETF=-\n",
      "2.77e+02|0:01:00|2.77e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.19ms/ev|maxl=-662.57|ETF=-\n",
      "3.24e+02|0:01:10|3.22e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.15ms/ev|maxl=-662.57|ETF=-\n",
      "3.70e+02|0:01:20|3.70e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.20ms/ev|maxl=-662.57|ETF=-\n",
      "4.16e+02|0:01:30|4.15e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.18ms/ev|maxl=-662.57|ETF=-\n",
      "4.64e+02|0:01:40|4.63e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.09ms/ev|maxl=-662.57|ETF=-\n",
      "5.11e+02|0:01:50|5.11e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.17ms/ev|maxl=-662.57|ETF=-\n",
      "5.57e+02|0:02:00|5.56e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.19ms/ev|maxl=-662.57|ETF=-\n",
      "6.05e+02|0:02:11|6.04e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.13ms/ev|maxl=-662.57|ETF=-\n",
      "6.53e+02|0:02:21|6.52e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.11ms/ev|maxl=-662.57|ETF=-\n",
      "6.98e+02|0:02:31|6.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.24ms/ev|maxl=-662.57|ETF=-\n",
      "7.45e+02|0:02:41|7.45e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.16ms/ev|maxl=-662.57|ETF=-\n",
      "7.92e+02|0:02:51|7.90e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.14ms/ev|maxl=-662.57|ETF=-\n",
      "8.40e+02|0:03:01|8.38e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.12ms/ev|maxl=-662.57|ETF=-\n",
      "8.88e+02|0:03:12|8.86e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.12ms/ev|maxl=-662.57|ETF=-\n",
      "9.34e+02|0:03:22|9.34e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.20ms/ev|maxl=-662.57|ETF=-\n",
      "9.81e+02|0:03:32|9.79e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.17ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "20:59 bilby INFO    : Adaptation of temperature chains finished at step 1000\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "1.03e+03|0:03:42|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.12ms/ev|maxl=-662.57|ETF=-\n",
      "1.08e+03|0:03:52|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.13ms/ev|maxl=-662.57|ETF=-\n",
      "1.13e+03|0:04:02|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.08ms/ev|maxl=-662.57|ETF=-\n",
      "1.18e+03|0:04:13|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.08ms/ev|maxl=-662.57|ETF=-\n",
      "1.22e+03|0:04:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.15ms/ev|maxl=-662.57|ETF=-\n",
      "1.27e+03|0:04:33|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.19ms/ev|maxl=-662.57|ETF=-\n",
      "1.32e+03|0:04:43|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.18ms/ev|maxl=-662.57|ETF=-\n",
      "1.36e+03|0:04:53|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.17ms/ev|maxl=-662.57|ETF=-\n",
      "1.41e+03|0:05:03|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.13ms/ev|maxl=-662.57|ETF=-\n",
      "1.46e+03|0:05:14|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.12ms/ev|maxl=-662.57|ETF=-\n",
      "1.51e+03|0:05:24|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.11ms/ev|maxl=-662.57|ETF=-\n",
      "1.55e+03|0:05:34|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.14ms/ev|maxl=-662.57|ETF=-\n",
      "1.60e+03|0:05:44|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.08ms/ev|maxl=-662.57|ETF=-\n",
      "1.65e+03|0:05:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.21ms/ev|maxl=-662.57|ETF=-\n",
      "1.70e+03|0:06:04|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.08ms/ev|maxl=-662.57|ETF=-\n",
      "1.75e+03|0:06:14|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.07ms/ev|maxl=-662.57|ETF=-\n",
      "1.79e+03|0:06:25|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.13ms/ev|maxl=-662.57|ETF=-\n",
      "1.84e+03|0:06:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.11ms/ev|maxl=-662.57|ETF=-\n",
      "1.89e+03|0:06:45|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.09ms/ev|maxl=-662.57|ETF=-\n",
      "1.94e+03|0:06:55|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.11ms/ev|maxl=-662.57|ETF=-\n",
      "1.99e+03|0:07:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.11ms/ev|maxl=-662.57|ETF=-\n",
      "2.04e+03|0:07:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.03ms/ev|maxl=-662.57|ETF=-\n",
      "2.08e+03|0:07:25|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.10ms/ev|maxl=-662.57|ETF=-\n",
      "2.13e+03|0:07:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.14ms/ev|maxl=-662.57|ETF=-\n",
      "2.18e+03|0:07:45|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.02ms/ev|maxl=-662.57|ETF=-\n",
      "2.23e+03|0:07:56|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.06ms/ev|maxl=-662.57|ETF=-\n",
      "2.28e+03|0:08:06|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.06ms/ev|maxl=-662.57|ETF=-\n",
      "2.33e+03|0:08:16|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.05ms/ev|maxl=-662.57|ETF=-\n",
      "2.38e+03|0:08:26|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.06ms/ev|maxl=-662.57|ETF=-\n",
      "2.43e+03|0:08:36|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.07ms/ev|maxl=-662.57|ETF=-\n",
      "2.48e+03|0:08:46|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.03ms/ev|maxl=-662.57|ETF=-\n",
      "2.52e+03|0:08:56|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.06ms/ev|maxl=-662.57|ETF=-\n",
      "2.57e+03|0:09:06|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.15ms/ev|maxl=-662.57|ETF=-\n",
      "2.62e+03|0:09:16|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.08ms/ev|maxl=-662.57|ETF=-\n",
      "2.67e+03|0:09:27|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.11ms/ev|maxl=-662.57|ETF=-\n",
      "2.72e+03|0:09:37|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.08ms/ev|maxl=-662.57|ETF=-\n",
      "2.76e+03|0:09:47|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.10ms/ev|maxl=-662.57|ETF=-\n",
      "2.81e+03|0:09:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.14ms/ev|maxl=-662.57|ETF=-\n",
      "2.86e+03|0:10:07|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.06ms/ev|maxl=-662.57|ETF=-\n",
      "2.91e+03|0:10:17|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.05ms/ev|maxl=-662.57|ETF=-\n",
      "2.96e+03|0:10:27|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.07ms/ev|maxl=-662.57|ETF=-\n",
      "3.01e+03|0:10:37|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.06ms/ev|maxl=-662.57|ETF=-\n",
      "3.06e+03|0:10:47|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.04ms/ev|maxl=-662.57|ETF=-\n",
      "3.10e+03|0:10:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.10ms/ev|maxl=-662.57|ETF=-\n",
      "3.15e+03|0:11:07|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.19ms/ev|maxl=-662.57|ETF=-\n",
      "3.20e+03|0:11:17|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.06ms/ev|maxl=-662.57|ETF=-\n",
      "3.25e+03|0:11:27|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.19ms/ev|maxl=-662.57|ETF=-\n",
      "3.30e+03|0:11:38|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.07ms/ev|maxl=-662.57|ETF=-\n",
      "3.34e+03|0:11:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.10ms/ev|maxl=-662.57|ETF=-\n",
      "3.39e+03|0:11:58|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.16ms/ev|maxl=-662.57|ETF=-\n",
      "3.44e+03|0:12:08|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.03ms/ev|maxl=-662.57|ETF=-\n",
      "3.49e+03|0:12:18|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.03ms/ev|maxl=-662.57|ETF=-\n",
      "3.54e+03|0:12:28|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.05ms/ev|maxl=-662.57|ETF=-\n",
      "3.59e+03|0:12:38|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.16ms/ev|maxl=-662.57|ETF=-\n",
      "3.63e+03|0:12:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.21ms/ev|maxl=-662.57|ETF=-\n",
      "3.68e+03|0:12:58|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.18ms/ev|maxl=-662.57|ETF=-\n",
      "3.72e+03|0:13:09|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.16ms/ev|maxl=-662.57|ETF=-\n",
      "3.77e+03|0:13:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.08ms/ev|maxl=-662.57|ETF=-\n",
      "3.82e+03|0:13:29|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.14ms/ev|maxl=-662.57|ETF=-\n",
      "3.87e+03|0:13:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.10ms/ev|maxl=-662.57|ETF=-\n",
      "3.91e+03|0:13:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.17ms/ev|maxl=-662.57|ETF=-\n",
      "3.96e+03|0:13:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.10ms/ev|maxl=-662.57|ETF=-\n",
      "4.01e+03|0:14:09|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.11ms/ev|maxl=-662.57|ETF=-\n",
      "4.06e+03|0:14:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.08ms/ev|maxl=-662.57|ETF=-\n",
      "4.11e+03|0:14:29|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.13ms/ev|maxl=-662.57|ETF=-\n",
      "4.16e+03|0:14:40|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.12ms/ev|maxl=-662.57|ETF=-\n",
      "4.20e+03|0:14:50|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.08ms/ev|maxl=-662.57|ETF=-\n",
      "4.25e+03|0:15:00|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.11ms/ev|maxl=-662.57|ETF=-\n",
      "4.30e+03|0:15:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.10ms/ev|maxl=-662.57|ETF=-\n",
      "4.35e+03|0:15:20|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.10ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "/home/avaj040/.cache/pypoetry/virtualenvs/funnel-ZrW66eTN-py3.8/lib/python3.8/site-packages/sklearn/base.py:1151: ConvergenceWarning: Number of distinct clusters (2) found smaller than n_clusters (10). Possibly due to duplicate points in X.\n",
      "  return fit_method(estimator, *args, **kwargs)\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.39e+03|0:15:30|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.29ms/ev|maxl=-662.57|ETF=-\n",
      "4.44e+03|0:15:40|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.29ms/ev|maxl=-662.57|ETF=-\n",
      "4.48e+03|0:15:50|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.30ms/ev|maxl=-662.57|ETF=-\n",
      "4.52e+03|0:16:00|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|2.29ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.54e+03|0:16:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|7.13ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.55e+03|0:16:21|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|10.01ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.56e+03|0:16:32|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|10.71ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.57e+03|0:16:42|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|10.30ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.58e+03|0:16:53|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|10.07ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.59e+03|0:17:04|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|9.66ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.60e+03|0:17:14|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|9.73ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.61e+03|0:17:25|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|10.24ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "/home/avaj040/.cache/pypoetry/virtualenvs/funnel-ZrW66eTN-py3.8/lib/python3.8/site-packages/sklearn/base.py:1151: ConvergenceWarning: Number of distinct clusters (2) found smaller than n_clusters (10). Possibly due to duplicate points in X.\n",
      "  return fit_method(estimator, *args, **kwargs)\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.62e+03|0:17:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|10.42ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.63e+03|0:17:46|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|9.73ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.64e+03|0:17:56|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|9.67ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error singular matrix\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.65e+03|0:18:07|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|10.14ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.66e+03|0:18:17|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|9.80ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "/home/avaj040/.cache/pypoetry/virtualenvs/funnel-ZrW66eTN-py3.8/lib/python3.8/site-packages/sklearn/base.py:1151: ConvergenceWarning: Number of distinct clusters (2) found smaller than n_clusters (10). Possibly due to duplicate points in X.\n",
      "  return fit_method(estimator, *args, **kwargs)\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.68e+03|0:18:28|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|9.94ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.69e+03|0:18:38|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|10.10ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.70e+03|0:18:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|10.03ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.70e+03|0:19:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|19.96ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.71e+03|0:19:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|21.11ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.71e+03|0:19:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|20.24ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.72e+03|0:19:34|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|22.84ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.72e+03|0:19:46|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|20.03ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.73e+03|0:19:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|19.20ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.74e+03|0:20:09|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|19.20ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.74e+03|0:20:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|20.23ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "/home/avaj040/.cache/pypoetry/virtualenvs/funnel-ZrW66eTN-py3.8/lib/python3.8/site-packages/sklearn/base.py:1151: ConvergenceWarning: Number of distinct clusters (1) found smaller than n_clusters (10). Possibly due to duplicate points in X.\n",
      "  return fit_method(estimator, *args, **kwargs)\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.75e+03|0:20:30|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|22.50ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.75e+03|0:20:42|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|23.57ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.76e+03|0:20:52|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|20.49ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.76e+03|0:21:03|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|22.33ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.77e+03|0:21:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|19.87ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.77e+03|0:21:26|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|21.92ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.78e+03|0:21:37|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|21.27ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.78e+03|0:21:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|23.56ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.79e+03|0:21:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|21.52ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.79e+03|0:22:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|35.99ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.79e+03|0:22:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|30.85ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.80e+03|0:22:36|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|32.94ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.80e+03|0:22:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|30.43ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.81e+03|0:22:58|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|25.35ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.81e+03|0:23:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|32.36ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.81e+03|0:23:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|30.08ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.82e+03|0:23:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|30.34ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.82e+03|0:23:46|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|28.10ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.83e+03|0:23:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|26.30ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.83e+03|0:24:08|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|29.33ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.83e+03|0:24:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|25.70ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.84e+03|0:24:30|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|27.24ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.84e+03|0:24:42|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|30.52ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.85e+03|0:24:52|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|26.07ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.85e+03|0:25:04|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|28.48ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.86e+03|0:25:17|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|26.30ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.86e+03|0:25:28|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|28.09ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.86e+03|0:25:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|27.98ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.87e+03|0:25:50|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|26.25ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.87e+03|0:26:02|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|30.49ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.88e+03|0:26:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|25.92ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.88e+03|0:26:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|26.62ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.88e+03|0:26:34|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|27.79ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.89e+03|0:26:47|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|31.90ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.89e+03|0:26:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|34.09ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.89e+03|0:27:09|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|30.37ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.90e+03|0:27:21|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|30.17ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.90e+03|0:27:32|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|36.08ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.90e+03|0:27:42|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|33.53ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.91e+03|0:27:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|38.75ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.91e+03|0:28:06|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|42.02ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.91e+03|0:28:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|42.31ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.92e+03|0:28:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|41.34ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.92e+03|0:28:43|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|37.67ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.92e+03|0:28:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|37.92ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.92e+03|0:29:04|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|34.02ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.93e+03|0:29:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|34.83ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.93e+03|0:29:26|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|36.63ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.93e+03|0:29:36|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|34.19ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.94e+03|0:29:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|33.47ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.94e+03|0:30:00|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|35.56ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:25 bilby INFO    : Checkpoint start\n",
      "21:25 bilby INFO    : Written checkpoint file outdir/lartillot_ptmc_d20_v0.01_resume.pickle\n",
      "21:25 bilby INFO    : Zero-temperature proposals:\n",
      "21:25 bilby INFO    : AdaptiveGaussianProposal(acceptance_ratio:0,n:9.4e+04,scale:1e-05,)\n",
      "21:25 bilby INFO    : DifferentialEvolutionProposal(acceptance_ratio:0,n:9.4e+04,)\n",
      "21:25 bilby INFO    : UniformProposal(acceptance_ratio:0,n:4.4e+03,)\n",
      "21:25 bilby INFO    : KDEProposal(acceptance_ratio:0,n:1e+05,trained:0,)\n",
      "21:25 bilby INFO    : FisherMatrixProposal(acceptance_ratio:0,n:1e+05,scale:1,)\n",
      "21:25 bilby INFO    : GMMProposal(acceptance_ratio:0,n:9.7e+04,trained:0,)\n",
      "21:25 bilby INFO    : Current taus={'x0': inf, 'x1': inf, 'x2': inf, 'x3': inf, 'x4': inf, 'x5': inf, 'x6': inf, 'x7': inf, 'x8': inf, 'x9': inf, 'x10': inf, 'x11': inf, 'x12': inf, 'x13': inf, 'x14': inf, 'x15': inf, 'x16': inf, 'x17': inf, 'x18': inf, 'x19': inf}\n",
      "21:25 bilby INFO    : Temperature swaps = 1646\n",
      "21:25 bilby INFO    : Temp:0<->1|beta=1|hot-samp=0|swap=0.00|conv=False|\n",
      "21:25 bilby INFO    : Temp:1<->2|beta=0.7169|hot-samp=4931|swap=1.00|conv=True|\n",
      "21:25 bilby INFO    : Temp:2<->3|beta=0.5139|hot-samp=4931|swap=0.00|conv=True|\n",
      "21:25 bilby INFO    : Temp:3<->4|beta=0.3684|hot-samp=0|swap=0.00|conv=False|\n",
      "21:25 bilby INFO    : Temp:4<->5|beta=0.2641|hot-samp=4931|swap=1.00|conv=True|\n",
      "21:25 bilby INFO    : Temp:5<->6|beta=0.1893|hot-samp=4931|swap=0.00|conv=True|\n",
      "21:25 bilby INFO    : Temp:6<->7|beta=0.1357|hot-samp=4931|swap=1.00|conv=True|\n",
      "21:25 bilby INFO    : Temp:7<->8|beta=0.09729|hot-samp=4931|swap=0.36|conv=True|\n",
      "21:25 bilby INFO    : Temp:8<->9|beta=0.06975|hot-samp=4931|swap=1.00|conv=True|\n",
      "21:25 bilby INFO    : Temp:9<->10|beta=0.05|hot-samp=4931|swap=-|conv=True|\n",
      "21:25 bilby INFO    : Creating diagnostic plots\n",
      "21:25 bilby INFO    : Checkpoint finished\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.94e+03|0:30:13|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|32.73ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.95e+03|0:30:24|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|35.13ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.95e+03|0:30:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|36.08ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.96e+03|0:30:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|33.12ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.96e+03|0:30:58|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|34.50ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.96e+03|0:31:09|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|35.82ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.96e+03|0:31:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|34.44ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.97e+03|0:31:30|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|35.06ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.97e+03|0:31:40|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|35.39ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.97e+03|0:31:51|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|34.24ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "/home/avaj040/.cache/pypoetry/virtualenvs/funnel-ZrW66eTN-py3.8/lib/python3.8/site-packages/sklearn/base.py:1151: ConvergenceWarning: Number of distinct clusters (2) found smaller than n_clusters (10). Possibly due to duplicate points in X.\n",
      "  return fit_method(estimator, *args, **kwargs)\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.98e+03|0:32:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|35.17ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.98e+03|0:32:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|35.15ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.98e+03|0:32:26|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|35.72ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.99e+03|0:32:37|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|35.98ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.99e+03|0:32:47|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|33.43ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "4.99e+03|0:32:58|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|37.60ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.00e+03|0:33:08|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|34.04ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.00e+03|0:33:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|34.30ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.00e+03|0:33:33|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|36.27ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.01e+03|0:33:46|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|33.76ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.01e+03|0:33:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|35.40ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.01e+03|0:34:08|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|37.55ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.02e+03|0:34:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|36.04ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.02e+03|0:34:29|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|33.74ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.02e+03|0:34:41|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|37.78ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.02e+03|0:34:51|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|34.12ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.03e+03|0:35:03|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|40.03ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.03e+03|0:35:16|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|43.21ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.03e+03|0:35:30|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|45.96ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.04e+03|0:35:42|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|40.47ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.04e+03|0:35:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|42.47ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.04e+03|0:36:08|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|46.14ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.04e+03|0:36:20|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|40.17ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.05e+03|0:36:33|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|41.57ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.05e+03|0:36:47|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|48.47ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.05e+03|0:36:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|56.01ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.06e+03|0:37:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|55.93ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.06e+03|0:37:21|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|55.16ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.06e+03|0:37:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|50.94ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.06e+03|0:37:43|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|58.46ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.06e+03|0:37:55|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|59.69ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.06e+03|0:38:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|53.71ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.07e+03|0:38:16|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|53.75ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.07e+03|0:38:32|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|52.66ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.07e+03|0:38:43|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|55.53ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.07e+03|0:38:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|53.58ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "/home/avaj040/.cache/pypoetry/virtualenvs/funnel-ZrW66eTN-py3.8/lib/python3.8/site-packages/sklearn/base.py:1151: ConvergenceWarning: Number of distinct clusters (2) found smaller than n_clusters (10). Possibly due to duplicate points in X.\n",
      "  return fit_method(estimator, *args, **kwargs)\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.08e+03|0:39:09|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|50.24ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.08e+03|0:39:26|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|56.87ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.08e+03|0:39:37|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|58.07ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.08e+03|0:39:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|60.22ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.09e+03|0:40:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|59.05ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.09e+03|0:40:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|54.73ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.09e+03|0:40:25|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|66.09ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.09e+03|0:40:38|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|61.32ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.09e+03|0:40:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|56.59ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.10e+03|0:41:00|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|52.80ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.10e+03|0:41:14|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|47.42ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "/home/avaj040/.cache/pypoetry/virtualenvs/funnel-ZrW66eTN-py3.8/lib/python3.8/site-packages/sklearn/base.py:1151: ConvergenceWarning: Number of distinct clusters (1) found smaller than n_clusters (10). Possibly due to duplicate points in X.\n",
      "  return fit_method(estimator, *args, **kwargs)\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.10e+03|0:41:26|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|59.91ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.10e+03|0:41:37|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|57.78ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.11e+03|0:41:52|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|50.01ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.11e+03|0:42:03|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|51.17ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.11e+03|0:42:13|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|50.97ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.11e+03|0:42:24|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|57.28ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.11e+03|0:42:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|53.56ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.12e+03|0:42:45|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|51.74ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.12e+03|0:42:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|56.16ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.12e+03|0:43:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|67.72ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.12e+03|0:43:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|58.34ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.12e+03|0:43:34|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|61.33ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.13e+03|0:43:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|48.84ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.13e+03|0:43:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|53.87ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.13e+03|0:44:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|53.14ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.13e+03|0:44:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|63.05ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.14e+03|0:44:34|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|54.25ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.14e+03|0:44:44|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|51.77ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.14e+03|0:44:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|51.58ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.14e+03|0:45:06|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|58.45ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.14e+03|0:45:18|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|63.03ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.14e+03|0:45:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|60.23ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.15e+03|0:45:41|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|53.09ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.15e+03|0:45:52|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|54.10ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.15e+03|0:46:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|62.79ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.15e+03|0:46:18|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|68.11ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.16e+03|0:46:29|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|52.81ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.16e+03|0:46:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|52.79ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.16e+03|0:46:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|50.67ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.16e+03|0:47:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|55.69ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.16e+03|0:47:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|57.25ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.16e+03|0:47:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|52.16ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.17e+03|0:47:32|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|50.10ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.17e+03|0:47:42|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|50.08ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.17e+03|0:47:53|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|53.89ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.17e+03|0:48:04|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|54.73ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.18e+03|0:48:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|53.34ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.18e+03|0:48:25|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|51.39ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.18e+03|0:48:36|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|52.25ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.18e+03|0:48:46|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|52.32ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.18e+03|0:48:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|56.07ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.18e+03|0:49:08|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|52.50ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.19e+03|0:49:18|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|52.01ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.19e+03|0:49:33|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|48.90ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.19e+03|0:49:46|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|63.78ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.19e+03|0:49:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|58.42ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.20e+03|0:50:08|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|53.14ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.20e+03|0:50:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|54.57ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.20e+03|0:50:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|54.50ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.20e+03|0:50:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|65.30ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.20e+03|0:50:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|51.82ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "/home/avaj040/.cache/pypoetry/virtualenvs/funnel-ZrW66eTN-py3.8/lib/python3.8/site-packages/sklearn/base.py:1151: ConvergenceWarning: Number of distinct clusters (2) found smaller than n_clusters (10). Possibly due to duplicate points in X.\n",
      "  return fit_method(estimator, *args, **kwargs)\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.21e+03|0:51:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|69.41ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.21e+03|0:51:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|53.58ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.21e+03|0:51:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|61.52ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.21e+03|0:51:47|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|58.09ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.22e+03|0:51:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|59.56ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.22e+03|0:52:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|59.50ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.22e+03|0:52:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|59.09ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.22e+03|0:52:36|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|68.56ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.22e+03|0:52:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|56.90ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.22e+03|0:53:00|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|61.34ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.23e+03|0:53:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|52.87ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.23e+03|0:53:21|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|50.62ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.23e+03|0:53:33|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|58.91ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.23e+03|0:53:45|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|60.86ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.24e+03|0:53:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|61.47ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.24e+03|0:54:08|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|57.20ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.24e+03|0:54:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|52.52ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.24e+03|0:54:32|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|67.11ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.24e+03|0:54:45|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|61.82ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.24e+03|0:54:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|59.57ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.25e+03|0:55:13|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|54.18ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.25e+03|0:55:25|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|62.05ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.25e+03|0:55:36|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|54.67ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.25e+03|0:55:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|64.93ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.26e+03|0:56:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|58.62ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.26e+03|0:56:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|56.02ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.26e+03|0:56:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|53.28ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "/home/avaj040/.cache/pypoetry/virtualenvs/funnel-ZrW66eTN-py3.8/lib/python3.8/site-packages/sklearn/base.py:1151: ConvergenceWarning: Number of distinct clusters (3) found smaller than n_clusters (10). Possibly due to duplicate points in X.\n",
      "  return fit_method(estimator, *args, **kwargs)\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.26e+03|0:56:34|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|56.63ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.26e+03|0:56:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|66.67ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.27e+03|0:56:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|59.31ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.27e+03|0:57:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|58.00ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.27e+03|0:57:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|53.98ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.27e+03|0:57:33|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|57.41ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.27e+03|0:57:46|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|64.82ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.28e+03|0:57:58|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|57.55ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.28e+03|0:58:08|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|51.05ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.28e+03|0:58:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|54.89ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.28e+03|0:58:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|61.98ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.28e+03|0:58:45|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|68.16ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.29e+03|0:58:56|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|54.27ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.29e+03|0:59:06|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|53.06ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.29e+03|0:59:18|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|58.83ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.29e+03|0:59:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|64.03ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.29e+03|0:59:42|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|55.60ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.30e+03|0:59:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|61.45ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby INFO    : Checkpoint start\n",
      "21:55 bilby INFO    : Written checkpoint file outdir/lartillot_ptmc_d20_v0.01_resume.pickle\n",
      "21:55 bilby INFO    : Zero-temperature proposals:\n",
      "21:55 bilby INFO    : AdaptiveGaussianProposal(acceptance_ratio:0,n:1e+05,scale:1e-05,)\n",
      "21:55 bilby INFO    : DifferentialEvolutionProposal(acceptance_ratio:0,n:1e+05,)\n",
      "21:55 bilby INFO    : UniformProposal(acceptance_ratio:0,n:4.7e+03,)\n",
      "21:55 bilby INFO    : KDEProposal(acceptance_ratio:0,n:1.1e+05,trained:0,)\n",
      "21:55 bilby INFO    : FisherMatrixProposal(acceptance_ratio:0,n:1.1e+05,scale:1,)\n",
      "21:55 bilby INFO    : GMMProposal(acceptance_ratio:0,n:1e+05,trained:1,)\n",
      "21:55 bilby INFO    : Current taus={'x0': inf, 'x1': inf, 'x2': inf, 'x3': inf, 'x4': inf, 'x5': inf, 'x6': inf, 'x7': inf, 'x8': inf, 'x9': inf, 'x10': inf, 'x11': inf, 'x12': inf, 'x13': inf, 'x14': inf, 'x15': inf, 'x16': inf, 'x17': inf, 'x18': inf, 'x19': inf}\n",
      "21:55 bilby INFO    : Temperature swaps = 1765\n",
      "21:55 bilby INFO    : Temp:0<->1|beta=1|hot-samp=0|swap=0.00|conv=False|\n",
      "21:55 bilby INFO    : Temp:1<->2|beta=0.7169|hot-samp=5287|swap=1.00|conv=True|\n",
      "21:55 bilby INFO    : Temp:2<->3|beta=0.5139|hot-samp=5287|swap=0.00|conv=True|\n",
      "21:55 bilby INFO    : Temp:3<->4|beta=0.3684|hot-samp=0|swap=0.00|conv=False|\n",
      "21:55 bilby INFO    : Temp:4<->5|beta=0.2641|hot-samp=5287|swap=1.00|conv=True|\n",
      "21:55 bilby INFO    : Temp:5<->6|beta=0.1893|hot-samp=5287|swap=0.00|conv=True|\n",
      "21:55 bilby INFO    : Temp:6<->7|beta=0.1357|hot-samp=5287|swap=1.00|conv=True|\n",
      "21:55 bilby INFO    : Temp:7<->8|beta=0.09729|hot-samp=5287|swap=0.36|conv=True|\n",
      "21:55 bilby INFO    : Temp:8<->9|beta=0.06975|hot-samp=5287|swap=1.00|conv=True|\n",
      "21:55 bilby INFO    : Temp:9<->10|beta=0.05|hot-samp=5287|swap=-|conv=True|\n",
      "21:55 bilby INFO    : Creating diagnostic plots\n",
      "21:55 bilby INFO    : Checkpoint finished\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.30e+03|1:00:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|55.24ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.30e+03|1:00:21|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|51.32ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.30e+03|1:00:32|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|57.06ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.30e+03|1:00:44|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|58.46ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.31e+03|1:00:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|50.99ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.31e+03|1:01:06|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|56.82ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.31e+03|1:01:16|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|50.77ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.31e+03|1:01:27|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|56.91ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.32e+03|1:01:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|59.82ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.32e+03|1:01:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|51.61ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.32e+03|1:02:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|53.03ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.32e+03|1:02:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|50.09ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.32e+03|1:02:27|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|59.18ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.33e+03|1:02:38|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|57.07ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.33e+03|1:02:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|51.38ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.33e+03|1:02:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|50.65ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.33e+03|1:03:09|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|52.25ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.33e+03|1:03:21|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|58.07ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.34e+03|1:03:32|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|57.58ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.34e+03|1:03:47|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|50.29ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.34e+03|1:03:58|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|53.62ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.34e+03|1:04:09|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|55.23ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "21:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.34e+03|1:04:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|68.28ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.35e+03|1:04:33|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|51.51ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.35e+03|1:04:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|52.63ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.35e+03|1:05:00|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|56.00ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.35e+03|1:05:13|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|62.26ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.36e+03|1:05:25|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|59.81ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.36e+03|1:05:36|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|55.08ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.36e+03|1:05:47|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|54.87ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.36e+03|1:05:58|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|56.82ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.36e+03|1:06:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|61.39ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.37e+03|1:06:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|61.81ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.37e+03|1:06:33|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|53.70ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.37e+03|1:06:44|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|52.96ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.37e+03|1:06:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|50.57ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.37e+03|1:07:07|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|63.01ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.38e+03|1:07:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|60.34ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.38e+03|1:07:29|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|50.27ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.38e+03|1:07:41|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|60.79ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.38e+03|1:07:51|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|52.22ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.38e+03|1:08:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|66.25ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.39e+03|1:08:17|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|64.32ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.39e+03|1:08:28|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|51.25ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.39e+03|1:08:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|55.79ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.39e+03|1:08:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|50.54ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.39e+03|1:09:02|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|63.17ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.40e+03|1:09:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|68.76ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.40e+03|1:09:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|50.69ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.40e+03|1:09:41|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|50.82ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.40e+03|1:09:52|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|55.41ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.40e+03|1:10:02|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|51.75ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.41e+03|1:10:13|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|55.86ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.41e+03|1:10:26|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|65.49ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.41e+03|1:10:37|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|51.06ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.41e+03|1:10:47|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|52.88ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.42e+03|1:10:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|58.89ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.42e+03|1:11:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|60.59ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.42e+03|1:11:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|53.96ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.42e+03|1:11:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|63.20ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.42e+03|1:11:45|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|53.60ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.42e+03|1:11:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|58.47ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.43e+03|1:12:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|66.55ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.43e+03|1:12:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|56.49ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.43e+03|1:12:34|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|61.81ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.43e+03|1:12:45|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|54.45ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.44e+03|1:12:58|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|66.75ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.44e+03|1:13:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|58.49ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.44e+03|1:13:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|59.78ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.44e+03|1:13:34|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|61.84ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.44e+03|1:13:45|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|52.01ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.44e+03|1:13:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|61.86ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.45e+03|1:14:09|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|62.49ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.45e+03|1:14:20|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|55.15ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.45e+03|1:14:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|52.62ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.45e+03|1:14:43|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|59.03ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.46e+03|1:14:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|55.18ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.46e+03|1:15:08|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|68.40ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.46e+03|1:15:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|55.85ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.46e+03|1:15:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|59.73ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.46e+03|1:15:47|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|55.42ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.47e+03|1:16:00|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|64.77ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.47e+03|1:16:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|51.33ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.47e+03|1:16:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|55.13ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.47e+03|1:16:33|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|59.35ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.47e+03|1:16:45|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|55.76ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.48e+03|1:16:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|62.94ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.48e+03|1:17:09|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|58.30ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.48e+03|1:17:20|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|54.61ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.48e+03|1:17:30|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|53.52ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.48e+03|1:17:42|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|57.17ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.49e+03|1:17:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|62.10ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.49e+03|1:18:06|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|59.73ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.49e+03|1:18:20|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|66.95ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.49e+03|1:18:34|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|49.20ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.50e+03|1:18:47|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|64.38ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.50e+03|1:19:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|69.98ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.50e+03|1:19:16|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|50.76ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.50e+03|1:19:27|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|50.53ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.50e+03|1:19:38|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|56.33ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.51e+03|1:19:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|56.97ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.51e+03|1:20:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|57.77ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.51e+03|1:20:13|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|58.67ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.51e+03|1:20:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|51.49ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.51e+03|1:20:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|62.10ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.52e+03|1:20:47|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|61.28ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.52e+03|1:20:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|57.30ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "/home/avaj040/.cache/pypoetry/virtualenvs/funnel-ZrW66eTN-py3.8/lib/python3.8/site-packages/sklearn/base.py:1151: ConvergenceWarning: Number of distinct clusters (3) found smaller than n_clusters (10). Possibly due to duplicate points in X.\n",
      "  return fit_method(estimator, *args, **kwargs)\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.52e+03|1:21:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|63.26ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.52e+03|1:21:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|52.35ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.52e+03|1:21:34|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|58.53ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.53e+03|1:21:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|68.62ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.53e+03|1:22:00|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|63.12ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.53e+03|1:22:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|61.73ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.53e+03|1:22:25|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|62.14ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.53e+03|1:22:37|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|60.98ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.54e+03|1:22:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|59.57ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.54e+03|1:23:00|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|54.47ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.54e+03|1:23:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|55.77ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.54e+03|1:23:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|57.59ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.54e+03|1:23:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|60.71ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.55e+03|1:23:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|64.00ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.55e+03|1:24:00|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|62.73ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.55e+03|1:24:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|52.40ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.55e+03|1:24:26|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.84ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.55e+03|1:24:41|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|74.39ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.56e+03|1:24:56|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|73.62ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.56e+03|1:25:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.16ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.56e+03|1:25:25|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|63.77ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.56e+03|1:25:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|72.04ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.56e+03|1:25:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|72.88ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.57e+03|1:26:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.35ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.57e+03|1:26:25|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.75ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.57e+03|1:26:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|72.11ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.57e+03|1:26:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|71.18ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.57e+03|1:27:07|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|67.01ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.58e+03|1:27:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.37ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.58e+03|1:27:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.26ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.58e+03|1:27:52|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|65.75ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.58e+03|1:28:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|65.78ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.58e+03|1:28:21|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|76.78ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.59e+03|1:28:36|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.63ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.59e+03|1:28:51|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|76.90ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.59e+03|1:29:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|68.16ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.59e+03|1:29:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|73.29ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.59e+03|1:29:34|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.39ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.60e+03|1:29:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|72.44ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.60e+03|1:30:02|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|66.51ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:25 bilby INFO    : Checkpoint start\n",
      "22:25 bilby INFO    : Written checkpoint file outdir/lartillot_ptmc_d20_v0.01_resume.pickle\n",
      "22:25 bilby INFO    : Zero-temperature proposals:\n",
      "22:25 bilby INFO    : AdaptiveGaussianProposal(acceptance_ratio:0,n:1.1e+05,scale:1e-05,)\n",
      "22:25 bilby INFO    : DifferentialEvolutionProposal(acceptance_ratio:0,n:1.1e+05,)\n",
      "22:25 bilby INFO    : UniformProposal(acceptance_ratio:0,n:5e+03,)\n",
      "22:25 bilby INFO    : KDEProposal(acceptance_ratio:0,n:1.1e+05,trained:0,)\n",
      "22:25 bilby INFO    : FisherMatrixProposal(acceptance_ratio:0,n:1.2e+05,scale:1,)\n",
      "22:25 bilby INFO    : GMMProposal(acceptance_ratio:0,n:1.1e+05,trained:1,)\n",
      "22:25 bilby INFO    : Current taus={'x0': inf, 'x1': inf, 'x2': inf, 'x3': inf, 'x4': inf, 'x5': inf, 'x6': inf, 'x7': inf, 'x8': inf, 'x9': inf, 'x10': inf, 'x11': inf, 'x12': inf, 'x13': inf, 'x14': inf, 'x15': inf, 'x16': inf, 'x17': inf, 'x18': inf, 'x19': inf}\n",
      "22:25 bilby INFO    : Temperature swaps = 1865\n",
      "22:25 bilby INFO    : Temp:0<->1|beta=1|hot-samp=0|swap=0.00|conv=False|\n",
      "22:25 bilby INFO    : Temp:1<->2|beta=0.7169|hot-samp=5588|swap=1.00|conv=True|\n",
      "22:25 bilby INFO    : Temp:2<->3|beta=0.5139|hot-samp=5588|swap=0.00|conv=True|\n",
      "22:25 bilby INFO    : Temp:3<->4|beta=0.3684|hot-samp=0|swap=0.00|conv=False|\n",
      "22:25 bilby INFO    : Temp:4<->5|beta=0.2641|hot-samp=5588|swap=1.00|conv=True|\n",
      "22:25 bilby INFO    : Temp:5<->6|beta=0.1893|hot-samp=5588|swap=0.00|conv=True|\n",
      "22:25 bilby INFO    : Temp:6<->7|beta=0.1357|hot-samp=5588|swap=1.00|conv=True|\n",
      "22:25 bilby INFO    : Temp:7<->8|beta=0.09729|hot-samp=5588|swap=0.35|conv=True|\n",
      "22:25 bilby INFO    : Temp:8<->9|beta=0.06975|hot-samp=5588|swap=1.00|conv=True|\n",
      "22:25 bilby INFO    : Temp:9<->10|beta=0.05|hot-samp=5588|swap=-|conv=True|\n",
      "22:25 bilby INFO    : Creating diagnostic plots\n",
      "22:25 bilby INFO    : Checkpoint finished\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.60e+03|1:30:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|64.36ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.60e+03|1:30:29|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|70.13ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.60e+03|1:30:42|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|63.40ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.61e+03|1:30:56|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|70.13ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.61e+03|1:31:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|72.00ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.61e+03|1:31:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|65.38ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.61e+03|1:31:37|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|69.26ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.61e+03|1:31:50|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|61.78ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.62e+03|1:32:03|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|66.70ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.62e+03|1:32:17|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|72.34ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.62e+03|1:32:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|65.93ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.62e+03|1:32:44|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|66.98ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.62e+03|1:32:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|67.65ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.63e+03|1:33:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|67.26ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.63e+03|1:33:25|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|71.25ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.63e+03|1:33:38|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|66.06ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.63e+03|1:33:53|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|71.18ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.63e+03|1:34:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|64.59ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.64e+03|1:34:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|66.75ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.64e+03|1:34:36|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.70ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.64e+03|1:34:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|65.39ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.64e+03|1:35:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.66ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.64e+03|1:35:17|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|63.52ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.65e+03|1:35:33|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.26ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.65e+03|1:35:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|74.25ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.65e+03|1:36:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|65.60ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.65e+03|1:36:16|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|74.22ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.65e+03|1:36:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|72.86ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.66e+03|1:36:45|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|72.67ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.66e+03|1:37:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.52ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.66e+03|1:37:13|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|64.05ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.66e+03|1:37:27|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|68.26ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.66e+03|1:37:40|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|65.54ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.67e+03|1:37:56|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.49ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.67e+03|1:38:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|76.01ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.67e+03|1:38:25|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|69.00ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.67e+03|1:38:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|71.87ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.67e+03|1:38:53|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|68.60ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.68e+03|1:39:09|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.45ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.68e+03|1:39:25|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.83ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.68e+03|1:39:40|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.88ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.68e+03|1:39:55|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|73.67ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.68e+03|1:40:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.32ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.69e+03|1:40:27|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.92ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.69e+03|1:40:44|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.44ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.69e+03|1:40:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.66ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.69e+03|1:41:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.35ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.69e+03|1:41:30|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|70.49ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.70e+03|1:41:47|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.86ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.70e+03|1:42:03|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.25ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.70e+03|1:42:18|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.89ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.70e+03|1:42:33|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|73.55ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.70e+03|1:42:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|74.13ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.71e+03|1:43:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.43ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.71e+03|1:43:21|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.16ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.71e+03|1:43:36|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|74.69ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.71e+03|1:43:52|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.74ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.71e+03|1:44:08|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.04ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.72e+03|1:44:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|73.54ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.72e+03|1:44:40|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.40ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.72e+03|1:44:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|69.17ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.72e+03|1:45:08|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|71.95ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.72e+03|1:45:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|72.62ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.73e+03|1:45:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.65ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.73e+03|1:45:56|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.34ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.73e+03|1:46:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|73.81ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.73e+03|1:46:27|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.97ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.73e+03|1:46:43|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.48ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.74e+03|1:46:58|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|73.25ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.74e+03|1:47:14|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.94ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.74e+03|1:47:30|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.25ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.74e+03|1:47:44|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|69.81ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.74e+03|1:48:02|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.04ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.75e+03|1:48:16|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|73.51ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.75e+03|1:48:33|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.50ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.75e+03|1:48:51|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.32ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.75e+03|1:49:06|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.05ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.75e+03|1:49:21|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|74.35ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.76e+03|1:49:38|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.67ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.76e+03|1:49:55|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.85ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.76e+03|1:50:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|74.36ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.76e+03|1:50:25|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.85ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.76e+03|1:50:40|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.97ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.77e+03|1:50:58|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.21ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.77e+03|1:51:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.06ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.77e+03|1:51:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.90ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.77e+03|1:51:46|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|70.36ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.77e+03|1:52:03|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.15ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.78e+03|1:52:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.61ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.78e+03|1:52:36|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.30ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.78e+03|1:52:52|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.42ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.78e+03|1:53:07|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.13ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.78e+03|1:53:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.07ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.79e+03|1:53:38|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.62ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.79e+03|1:53:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.52ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.79e+03|1:54:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.95ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.79e+03|1:54:26|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.58ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.79e+03|1:54:42|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.11ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.80e+03|1:54:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.29ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.80e+03|1:55:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.46ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.80e+03|1:55:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.35ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.80e+03|1:55:45|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|69.29ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.80e+03|1:56:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.38ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.81e+03|1:56:16|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.02ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.81e+03|1:56:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|92.42ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.81e+03|1:56:50|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.45ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.81e+03|1:57:06|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.11ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.81e+03|1:57:21|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.94ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.82e+03|1:57:36|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|74.55ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.82e+03|1:57:53|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.21ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.82e+03|1:58:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.62ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.82e+03|1:58:25|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|76.61ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.82e+03|1:58:41|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.78ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.83e+03|1:58:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.75ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.83e+03|1:59:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.02ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.83e+03|1:59:29|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.46ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.83e+03|1:59:44|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.82ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.83e+03|2:00:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.93ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:55 bilby INFO    : Checkpoint start\n",
      "22:55 bilby INFO    : Written checkpoint file outdir/lartillot_ptmc_d20_v0.01_resume.pickle\n",
      "22:55 bilby INFO    : Zero-temperature proposals:\n",
      "22:55 bilby INFO    : AdaptiveGaussianProposal(acceptance_ratio:0,n:1.1e+05,scale:1e-05,)\n",
      "22:55 bilby INFO    : DifferentialEvolutionProposal(acceptance_ratio:0,n:1.1e+05,)\n",
      "22:55 bilby INFO    : UniformProposal(acceptance_ratio:0,n:5.2e+03,)\n",
      "22:55 bilby INFO    : KDEProposal(acceptance_ratio:0,n:1.2e+05,trained:0,)\n",
      "22:55 bilby INFO    : FisherMatrixProposal(acceptance_ratio:0,n:1.2e+05,scale:1,)\n",
      "22:55 bilby INFO    : GMMProposal(acceptance_ratio:0,n:1.1e+05,trained:1,)\n",
      "22:55 bilby INFO    : Current taus={'x0': inf, 'x1': inf, 'x2': inf, 'x3': inf, 'x4': inf, 'x5': inf, 'x6': inf, 'x7': inf, 'x8': inf, 'x9': inf, 'x10': inf, 'x11': inf, 'x12': inf, 'x13': inf, 'x14': inf, 'x15': inf, 'x16': inf, 'x17': inf, 'x18': inf, 'x19': inf}\n",
      "22:55 bilby INFO    : Temperature swaps = 1944\n",
      "22:55 bilby INFO    : Temp:0<->1|beta=1|hot-samp=0|swap=0.00|conv=False|\n",
      "22:55 bilby INFO    : Temp:1<->2|beta=0.7169|hot-samp=5824|swap=1.00|conv=True|\n",
      "22:55 bilby INFO    : Temp:2<->3|beta=0.5139|hot-samp=5824|swap=0.00|conv=True|\n",
      "22:55 bilby INFO    : Temp:3<->4|beta=0.3684|hot-samp=0|swap=0.00|conv=False|\n",
      "22:55 bilby INFO    : Temp:4<->5|beta=0.2641|hot-samp=5824|swap=1.00|conv=True|\n",
      "22:55 bilby INFO    : Temp:5<->6|beta=0.1893|hot-samp=5824|swap=0.00|conv=True|\n",
      "22:55 bilby INFO    : Temp:6<->7|beta=0.1357|hot-samp=5824|swap=1.00|conv=True|\n",
      "22:55 bilby INFO    : Temp:7<->8|beta=0.09729|hot-samp=5824|swap=0.35|conv=True|\n",
      "22:55 bilby INFO    : Temp:8<->9|beta=0.06975|hot-samp=5824|swap=1.00|conv=True|\n",
      "22:55 bilby INFO    : Temp:9<->10|beta=0.05|hot-samp=5824|swap=-|conv=True|\n",
      "22:55 bilby INFO    : Creating diagnostic plots\n",
      "22:55 bilby INFO    : Checkpoint finished\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.84e+03|2:00:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|71.75ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.84e+03|2:00:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.51ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.84e+03|2:00:47|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.35ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.84e+03|2:01:02|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|73.71ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.84e+03|2:01:16|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|74.17ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.85e+03|2:01:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|72.20ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.85e+03|2:01:46|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|73.66ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.85e+03|2:02:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.37ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.85e+03|2:02:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|69.12ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.85e+03|2:02:29|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|72.97ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.86e+03|2:02:44|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|73.39ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.86e+03|2:03:00|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.94ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.86e+03|2:03:18|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.29ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.86e+03|2:03:33|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|72.45ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.86e+03|2:03:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.20ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.87e+03|2:04:03|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|71.92ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "22:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.87e+03|2:04:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.72ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.87e+03|2:04:36|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.48ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.87e+03|2:04:50|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|71.57ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.87e+03|2:05:07|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.11ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.88e+03|2:05:24|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.13ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.88e+03|2:05:40|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.87ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.88e+03|2:05:56|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.60ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.88e+03|2:06:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|74.88ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.88e+03|2:06:27|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.60ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.89e+03|2:06:43|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.66ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.89e+03|2:06:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.88ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.89e+03|2:07:16|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.92ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.89e+03|2:07:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|76.82ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.89e+03|2:07:46|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|74.31ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.90e+03|2:08:02|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.14ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.90e+03|2:08:18|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.13ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.90e+03|2:08:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.96ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.90e+03|2:08:51|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.80ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.90e+03|2:09:07|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.04ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.91e+03|2:09:24|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.33ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.91e+03|2:09:41|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.91ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.91e+03|2:09:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.86ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.91e+03|2:10:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|70.32ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.91e+03|2:10:27|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.70ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.92e+03|2:10:44|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.59ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.92e+03|2:10:58|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|71.43ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.92e+03|2:11:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.97ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.92e+03|2:11:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.51ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.92e+03|2:11:47|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.97ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.93e+03|2:12:02|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.68ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.93e+03|2:12:18|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.06ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.93e+03|2:12:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.81ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.93e+03|2:12:51|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.80ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.93e+03|2:13:07|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|76.20ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.94e+03|2:13:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.45ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.94e+03|2:13:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.18ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.94e+03|2:13:55|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.99ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.94e+03|2:14:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.57ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.94e+03|2:14:24|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|69.44ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.95e+03|2:14:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|74.88ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.95e+03|2:14:55|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.30ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.95e+03|2:15:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.22ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.95e+03|2:15:28|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.25ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.95e+03|2:15:42|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|74.64ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.96e+03|2:15:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.61ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.96e+03|2:16:16|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.44ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.96e+03|2:16:34|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.97ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.96e+03|2:16:50|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.21ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.96e+03|2:17:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.79ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.97e+03|2:17:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.99ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.97e+03|2:17:37|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|74.32ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.97e+03|2:17:55|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|92.53ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.97e+03|2:18:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.09ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.97e+03|2:18:26|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|76.97ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.98e+03|2:18:41|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.94ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.98e+03|2:18:56|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.38ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.98e+03|2:19:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.00ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.98e+03|2:19:28|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.35ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.98e+03|2:19:43|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|72.98ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.99e+03|2:20:00|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.08ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.99e+03|2:20:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|76.52ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.99e+03|2:20:33|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.34ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.99e+03|2:20:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.55ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "5.99e+03|2:21:04|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.95ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.00e+03|2:21:21|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.66ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.00e+03|2:21:37|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.30ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.00e+03|2:21:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.43ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.00e+03|2:22:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.50ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.00e+03|2:22:27|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.83ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.01e+03|2:22:43|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.32ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.01e+03|2:23:00|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.17ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.01e+03|2:23:16|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.07ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.01e+03|2:23:34|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.31ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.01e+03|2:23:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.34ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.02e+03|2:24:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.69ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.02e+03|2:24:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.12ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.02e+03|2:24:41|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.83ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.02e+03|2:24:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.40ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.02e+03|2:25:14|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|76.77ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.03e+03|2:25:30|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.72ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.03e+03|2:25:46|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.73ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.03e+03|2:26:02|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.35ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.03e+03|2:26:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|104.95ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.03e+03|2:26:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|92.19ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.04e+03|2:26:47|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.65ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.04e+03|2:26:58|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|100.72ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.04e+03|2:27:14|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.11ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.04e+03|2:27:30|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.84ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.04e+03|2:27:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.60ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.04e+03|2:28:04|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.44ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.05e+03|2:28:20|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.39ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.05e+03|2:28:36|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.36ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.05e+03|2:28:53|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.29ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.05e+03|2:29:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|92.96ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.05e+03|2:29:29|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.23ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.06e+03|2:29:46|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.64ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.06e+03|2:30:04|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.46ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:25 bilby INFO    : Checkpoint start\n",
      "23:25 bilby INFO    : Written checkpoint file outdir/lartillot_ptmc_d20_v0.01_resume.pickle\n",
      "23:25 bilby INFO    : Zero-temperature proposals:\n",
      "23:25 bilby INFO    : AdaptiveGaussianProposal(acceptance_ratio:0,n:1.2e+05,scale:1e-05,)\n",
      "23:25 bilby INFO    : DifferentialEvolutionProposal(acceptance_ratio:0,n:1.2e+05,)\n",
      "23:25 bilby INFO    : UniformProposal(acceptance_ratio:0,n:5.4e+03,)\n",
      "23:25 bilby INFO    : KDEProposal(acceptance_ratio:0,n:1.2e+05,trained:0,)\n",
      "23:25 bilby INFO    : FisherMatrixProposal(acceptance_ratio:0,n:1.3e+05,scale:1,)\n",
      "23:25 bilby INFO    : GMMProposal(acceptance_ratio:0,n:1.2e+05,trained:1,)\n",
      "23:25 bilby INFO    : Current taus={'x0': inf, 'x1': inf, 'x2': inf, 'x3': inf, 'x4': inf, 'x5': inf, 'x6': inf, 'x7': inf, 'x8': inf, 'x9': inf, 'x10': inf, 'x11': inf, 'x12': inf, 'x13': inf, 'x14': inf, 'x15': inf, 'x16': inf, 'x17': inf, 'x18': inf, 'x19': inf}\n",
      "23:25 bilby INFO    : Temperature swaps = 2019\n",
      "23:25 bilby INFO    : Temp:0<->1|beta=1|hot-samp=0|swap=0.00|conv=False|\n",
      "23:25 bilby INFO    : Temp:1<->2|beta=0.7169|hot-samp=6048|swap=1.00|conv=True|\n",
      "23:25 bilby INFO    : Temp:2<->3|beta=0.5139|hot-samp=6048|swap=0.00|conv=True|\n",
      "23:25 bilby INFO    : Temp:3<->4|beta=0.3684|hot-samp=0|swap=0.00|conv=False|\n",
      "23:25 bilby INFO    : Temp:4<->5|beta=0.2641|hot-samp=6048|swap=1.00|conv=True|\n",
      "23:25 bilby INFO    : Temp:5<->6|beta=0.1893|hot-samp=6048|swap=0.00|conv=True|\n",
      "23:25 bilby INFO    : Temp:6<->7|beta=0.1357|hot-samp=6048|swap=1.00|conv=True|\n",
      "23:25 bilby INFO    : Temp:7<->8|beta=0.09729|hot-samp=6048|swap=0.35|conv=True|\n",
      "23:25 bilby INFO    : Temp:8<->9|beta=0.06975|hot-samp=6048|swap=1.00|conv=True|\n",
      "23:25 bilby INFO    : Temp:9<->10|beta=0.05|hot-samp=6048|swap=-|conv=True|\n",
      "23:25 bilby INFO    : Creating diagnostic plots\n",
      "23:26 bilby INFO    : Checkpoint finished\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.06e+03|2:30:20|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.29ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.06e+03|2:30:38|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.60ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.06e+03|2:30:53|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.71ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.07e+03|2:31:09|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.47ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.07e+03|2:31:25|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.87ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.07e+03|2:31:42|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.31ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.07e+03|2:32:00|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.65ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.07e+03|2:32:16|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.55ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.08e+03|2:32:32|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.29ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.08e+03|2:32:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.26ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.08e+03|2:33:04|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.02ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.08e+03|2:33:21|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.10ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.08e+03|2:33:38|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.47ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.09e+03|2:33:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.18ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.09e+03|2:34:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.62ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.09e+03|2:34:26|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.66ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.09e+03|2:34:43|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.00ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.09e+03|2:34:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.69ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.10e+03|2:35:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.44ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.10e+03|2:35:32|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.11ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.10e+03|2:35:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.70ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.10e+03|2:36:06|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.97ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.10e+03|2:36:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.84ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.11e+03|2:36:38|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.19ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.11e+03|2:36:53|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.16ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.11e+03|2:37:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.55ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.11e+03|2:37:26|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.40ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.11e+03|2:37:43|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.70ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.12e+03|2:37:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.44ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.12e+03|2:38:17|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.52ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.12e+03|2:38:32|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.59ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.12e+03|2:38:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.21ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.12e+03|2:39:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.55ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.13e+03|2:39:21|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.91ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.13e+03|2:39:37|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.51ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.13e+03|2:39:53|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.83ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.13e+03|2:40:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.64ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.13e+03|2:40:26|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.67ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.14e+03|2:40:40|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|73.81ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.14e+03|2:40:58|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.39ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.14e+03|2:41:14|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.45ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.14e+03|2:41:30|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.96ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.14e+03|2:41:47|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.88ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.15e+03|2:42:02|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|76.85ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.15e+03|2:42:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.94ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.15e+03|2:42:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.67ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.15e+03|2:42:52|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.28ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.15e+03|2:43:09|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.61ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.16e+03|2:43:24|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.08ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.16e+03|2:43:41|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.66ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.16e+03|2:43:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.20ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.16e+03|2:44:14|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.82ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.16e+03|2:44:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.14ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.17e+03|2:44:46|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.13ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.17e+03|2:45:02|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.08ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.17e+03|2:45:18|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.40ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.17e+03|2:45:36|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.38ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.17e+03|2:45:52|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.92ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.18e+03|2:46:07|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.80ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.18e+03|2:46:24|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.28ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.18e+03|2:46:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|74.99ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.18e+03|2:46:56|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.08ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.18e+03|2:47:13|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.56ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.19e+03|2:47:28|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.73ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.19e+03|2:47:44|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.52ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.19e+03|2:47:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.18ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.19e+03|2:48:17|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.11ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.19e+03|2:48:34|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.44ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.20e+03|2:48:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|76.65ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.20e+03|2:49:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.50ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.20e+03|2:49:21|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.51ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.20e+03|2:49:38|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.70ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.20e+03|2:49:55|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.39ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.21e+03|2:50:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.66ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.21e+03|2:50:27|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.09ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.21e+03|2:50:42|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|76.26ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.21e+03|2:51:00|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.81ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.21e+03|2:51:17|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.54ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.22e+03|2:51:32|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.26ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.22e+03|2:51:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.34ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.22e+03|2:52:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.46ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.22e+03|2:52:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.90ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.22e+03|2:52:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.96ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.23e+03|2:52:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|76.72ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.23e+03|2:53:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.00ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.23e+03|2:53:26|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|76.17ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.23e+03|2:53:42|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.27ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.23e+03|2:53:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.43ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.24e+03|2:54:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.25ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.24e+03|2:54:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.13ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.24e+03|2:54:46|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.74ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.24e+03|2:55:02|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.85ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.24e+03|2:55:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.01ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.25e+03|2:55:34|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.98ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.25e+03|2:55:50|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.13ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.25e+03|2:56:06|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.37ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.25e+03|2:56:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.38ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.25e+03|2:56:40|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.71ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.26e+03|2:56:56|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.79ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.26e+03|2:57:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.81ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.26e+03|2:57:27|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.30ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.26e+03|2:57:44|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.88ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.26e+03|2:58:02|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.41ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.27e+03|2:58:18|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.34ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.27e+03|2:58:32|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|74.06ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.27e+03|2:58:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.07ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.27e+03|2:59:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.80ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.27e+03|2:59:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|91.16ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.28e+03|2:59:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.73ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.28e+03|2:59:55|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.52ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby INFO    : Checkpoint start\n",
      "23:56 bilby INFO    : Written checkpoint file outdir/lartillot_ptmc_d20_v0.01_resume.pickle\n",
      "23:56 bilby INFO    : Zero-temperature proposals:\n",
      "23:56 bilby INFO    : AdaptiveGaussianProposal(acceptance_ratio:0,n:1.2e+05,scale:1e-05,)\n",
      "23:56 bilby INFO    : DifferentialEvolutionProposal(acceptance_ratio:0,n:1.2e+05,)\n",
      "23:56 bilby INFO    : UniformProposal(acceptance_ratio:0,n:5.6e+03,)\n",
      "23:56 bilby INFO    : KDEProposal(acceptance_ratio:0,n:1.3e+05,trained:0,)\n",
      "23:56 bilby INFO    : FisherMatrixProposal(acceptance_ratio:0,n:1.3e+05,scale:1,)\n",
      "23:56 bilby INFO    : GMMProposal(acceptance_ratio:0,n:1.2e+05,trained:1,)\n",
      "23:56 bilby INFO    : Current taus={'x0': inf, 'x1': inf, 'x2': inf, 'x3': inf, 'x4': inf, 'x5': inf, 'x6': inf, 'x7': inf, 'x8': inf, 'x9': inf, 'x10': inf, 'x11': inf, 'x12': inf, 'x13': inf, 'x14': inf, 'x15': inf, 'x16': inf, 'x17': inf, 'x18': inf, 'x19': inf}\n",
      "23:56 bilby INFO    : Temperature swaps = 2092\n",
      "23:56 bilby INFO    : Temp:0<->1|beta=1|hot-samp=0|swap=0.00|conv=False|\n",
      "23:56 bilby INFO    : Temp:1<->2|beta=0.7169|hot-samp=6269|swap=1.00|conv=True|\n",
      "23:56 bilby INFO    : Temp:2<->3|beta=0.5139|hot-samp=6269|swap=0.00|conv=True|\n",
      "23:56 bilby INFO    : Temp:3<->4|beta=0.3684|hot-samp=0|swap=0.00|conv=False|\n",
      "23:56 bilby INFO    : Temp:4<->5|beta=0.2641|hot-samp=6269|swap=1.00|conv=True|\n",
      "23:56 bilby INFO    : Temp:5<->6|beta=0.1893|hot-samp=6269|swap=0.00|conv=True|\n",
      "23:56 bilby INFO    : Temp:6<->7|beta=0.1357|hot-samp=6269|swap=1.00|conv=True|\n",
      "23:56 bilby INFO    : Temp:7<->8|beta=0.09729|hot-samp=6269|swap=0.35|conv=True|\n",
      "23:56 bilby INFO    : Temp:8<->9|beta=0.06975|hot-samp=6269|swap=1.00|conv=True|\n",
      "23:56 bilby INFO    : Temp:9<->10|beta=0.05|hot-samp=6269|swap=-|conv=True|\n",
      "23:56 bilby INFO    : Creating diagnostic plots\n",
      "23:56 bilby INFO    : Checkpoint finished\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.28e+03|3:00:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.25ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.28e+03|3:00:28|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.02ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.28e+03|3:00:45|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.24ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.29e+03|3:01:00|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.17ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.29e+03|3:01:16|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.74ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.29e+03|3:01:32|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.43ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.29e+03|3:01:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.09ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.29e+03|3:02:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.52ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.30e+03|3:02:21|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.33ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.30e+03|3:02:37|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.57ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.30e+03|3:02:53|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.57ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.30e+03|3:03:09|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.67ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.30e+03|3:03:26|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.28ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.31e+03|3:03:43|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.21ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "23:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.31e+03|3:03:58|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.89ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.31e+03|3:04:14|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.03ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.31e+03|3:04:30|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.65ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.31e+03|3:04:47|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.97ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.32e+03|3:05:02|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.64ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.32e+03|3:05:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.03ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.32e+03|3:05:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.38ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.32e+03|3:05:51|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.22ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.32e+03|3:06:08|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.73ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.33e+03|3:06:25|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.93ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.33e+03|3:06:41|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.35ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.33e+03|3:06:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.66ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.33e+03|3:07:13|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.13ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.33e+03|3:07:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.55ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.34e+03|3:07:47|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.62ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.34e+03|3:08:03|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|76.94ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.34e+03|3:08:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.00ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.34e+03|3:08:34|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.26ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.34e+03|3:08:51|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.83ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.35e+03|3:09:08|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.53ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.35e+03|3:09:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|76.87ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.35e+03|3:09:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.79ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.35e+03|3:09:55|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.65ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.35e+03|3:10:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.05ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.36e+03|3:10:29|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.60ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.36e+03|3:10:44|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.06ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.36e+03|3:11:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.98ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.36e+03|3:11:17|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.64ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.36e+03|3:11:34|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.26ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.37e+03|3:11:51|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.65ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.37e+03|3:12:06|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.21ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.37e+03|3:12:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.09ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.37e+03|3:12:38|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.30ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.37e+03|3:12:55|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.32ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.38e+03|3:13:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.02ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.38e+03|3:13:27|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|74.82ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.38e+03|3:13:44|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.91ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.38e+03|3:13:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.41ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.38e+03|3:14:16|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.97ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.39e+03|3:14:33|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.78ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.39e+03|3:14:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|76.27ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.39e+03|3:15:04|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.50ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.39e+03|3:15:20|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.05ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.39e+03|3:15:38|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.35ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.40e+03|3:15:55|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.34ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.40e+03|3:16:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.64ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.40e+03|3:16:27|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.59ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.40e+03|3:16:43|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.89ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.40e+03|3:17:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|91.04ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.41e+03|3:17:18|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.03ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.41e+03|3:17:34|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.84ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.41e+03|3:17:50|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.72ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.41e+03|3:18:06|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.52ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.41e+03|3:18:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.72ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.42e+03|3:18:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.38ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.42e+03|3:18:55|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.69ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.42e+03|3:19:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.17ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.42e+03|3:19:28|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.09ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.42e+03|3:19:44|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.76ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.43e+03|3:20:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.50ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.43e+03|3:20:17|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.47ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.43e+03|3:20:33|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.58ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.43e+03|3:20:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.56ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.43e+03|3:21:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.81ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.44e+03|3:21:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.06ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.44e+03|3:21:38|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.92ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.44e+03|3:21:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.90ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.44e+03|3:22:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.96ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.44e+03|3:22:29|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.36ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.45e+03|3:22:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|94.56ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.45e+03|3:23:06|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.80ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.45e+03|3:23:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.38ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.45e+03|3:23:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.49ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 10-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.45e+03|3:23:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.15ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.46e+03|3:24:07|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|103.42ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.46e+03|3:24:25|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|92.97ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.46e+03|3:24:42|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.71ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.46e+03|3:24:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.46ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.46e+03|3:25:17|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.45ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.46e+03|3:25:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|91.82ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.47e+03|3:25:53|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|91.48ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.47e+03|3:26:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.62ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.47e+03|3:26:28|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.43ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.47e+03|3:26:45|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.18ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.48e+03|3:27:04|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|95.81ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.48e+03|3:27:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.93ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.48e+03|3:27:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.30ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.48e+03|3:27:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.39ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.48e+03|3:28:14|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.83ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.48e+03|3:28:33|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|95.98ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.49e+03|3:28:43|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|100.73ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.49e+03|3:29:00|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.48ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.49e+03|3:29:17|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.88ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.49e+03|3:29:33|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.19ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.49e+03|3:29:51|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.46ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby INFO    : Checkpoint start\n",
      "00:26 bilby INFO    : Written checkpoint file outdir/lartillot_ptmc_d20_v0.01_resume.pickle\n",
      "00:26 bilby INFO    : Zero-temperature proposals:\n",
      "00:26 bilby INFO    : AdaptiveGaussianProposal(acceptance_ratio:0,n:1.2e+05,scale:1e-05,)\n",
      "00:26 bilby INFO    : DifferentialEvolutionProposal(acceptance_ratio:0,n:1.2e+05,)\n",
      "00:26 bilby INFO    : UniformProposal(acceptance_ratio:0,n:5.8e+03,)\n",
      "00:26 bilby INFO    : KDEProposal(acceptance_ratio:0,n:1.3e+05,trained:0,)\n",
      "00:26 bilby INFO    : FisherMatrixProposal(acceptance_ratio:0,n:1.4e+05,scale:1,)\n",
      "00:26 bilby INFO    : GMMProposal(acceptance_ratio:0,n:1.3e+05,trained:1,)\n",
      "00:26 bilby INFO    : Current taus={'x0': inf, 'x1': inf, 'x2': inf, 'x3': inf, 'x4': inf, 'x5': inf, 'x6': inf, 'x7': inf, 'x8': inf, 'x9': inf, 'x10': inf, 'x11': inf, 'x12': inf, 'x13': inf, 'x14': inf, 'x15': inf, 'x16': inf, 'x17': inf, 'x18': inf, 'x19': inf}\n",
      "00:26 bilby INFO    : Temperature swaps = 2164\n",
      "00:26 bilby INFO    : Temp:0<->1|beta=1|hot-samp=0|swap=0.00|conv=False|\n",
      "00:26 bilby INFO    : Temp:1<->2|beta=0.7169|hot-samp=6485|swap=1.00|conv=True|\n",
      "00:26 bilby INFO    : Temp:2<->3|beta=0.5139|hot-samp=6485|swap=0.00|conv=True|\n",
      "00:26 bilby INFO    : Temp:3<->4|beta=0.3684|hot-samp=0|swap=0.00|conv=False|\n",
      "00:26 bilby INFO    : Temp:4<->5|beta=0.2641|hot-samp=6485|swap=1.00|conv=True|\n",
      "00:26 bilby INFO    : Temp:5<->6|beta=0.1893|hot-samp=6485|swap=0.00|conv=True|\n",
      "00:26 bilby INFO    : Temp:6<->7|beta=0.1357|hot-samp=6485|swap=1.00|conv=True|\n",
      "00:26 bilby INFO    : Temp:7<->8|beta=0.09729|hot-samp=6485|swap=0.35|conv=True|\n",
      "00:26 bilby INFO    : Temp:8<->9|beta=0.06975|hot-samp=6485|swap=1.00|conv=True|\n",
      "00:26 bilby INFO    : Temp:9<->10|beta=0.05|hot-samp=6485|swap=-|conv=True|\n",
      "00:26 bilby INFO    : Creating diagnostic plots\n",
      "00:26 bilby INFO    : Checkpoint finished\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.50e+03|3:30:09|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.29ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.50e+03|3:30:27|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.90ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.50e+03|3:30:43|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.86ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.50e+03|3:31:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.72ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.50e+03|3:31:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.11ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.51e+03|3:31:36|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.87ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.51e+03|3:31:53|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.41ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.51e+03|3:32:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.32ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.51e+03|3:32:27|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.08ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.51e+03|3:32:43|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.97ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.52e+03|3:33:00|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.94ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.52e+03|3:33:16|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.52ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.52e+03|3:33:33|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.48ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.52e+03|3:33:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.19ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.52e+03|3:34:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.51ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.53e+03|3:34:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.24ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.53e+03|3:34:40|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.68ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.53e+03|3:34:56|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.48ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.53e+03|3:35:13|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.44ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.53e+03|3:35:28|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.79ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.54e+03|3:35:46|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.47ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.54e+03|3:36:03|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.02ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 9-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.54e+03|3:36:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.10ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.54e+03|3:36:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.96ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.54e+03|3:36:52|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.94ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.55e+03|3:37:09|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.59ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.55e+03|3:37:26|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.26ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.55e+03|3:37:42|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.94ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.55e+03|3:37:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.82ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.55e+03|3:38:14|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.57ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.56e+03|3:38:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.12ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.56e+03|3:38:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.97ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.56e+03|3:39:03|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|76.06ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.56e+03|3:39:20|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.08ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.56e+03|3:39:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.48ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.57e+03|3:39:52|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.69ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.57e+03|3:40:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.23ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.57e+03|3:40:25|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.15ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.57e+03|3:40:41|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.26ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.57e+03|3:40:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.18ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.58e+03|3:41:14|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.54ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.58e+03|3:41:32|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.78ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.58e+03|3:41:47|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.39ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.58e+03|3:42:03|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.53ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.58e+03|3:42:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.75ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.59e+03|3:42:37|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.91ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.59e+03|3:42:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.40ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.59e+03|3:43:09|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.20ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.59e+03|3:43:25|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.81ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.59e+03|3:43:41|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|76.94ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.60e+03|3:43:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|92.05ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.60e+03|3:44:16|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.85ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.60e+03|3:44:32|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.18ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.60e+03|3:44:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.12ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.60e+03|3:45:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.29ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.61e+03|3:45:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.41ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.61e+03|3:45:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.38ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.61e+03|3:45:55|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.56ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.61e+03|3:46:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.18ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.61e+03|3:46:28|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.42ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.62e+03|3:46:44|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.49ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.62e+03|3:47:02|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.29ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.62e+03|3:47:18|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.24ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.62e+03|3:47:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.76ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.62e+03|3:47:51|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.60ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.63e+03|3:48:08|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.20ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.63e+03|3:48:25|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.04ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.63e+03|3:48:41|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.88ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.63e+03|3:48:58|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.31ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.63e+03|3:49:14|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.18ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.64e+03|3:49:30|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.40ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.64e+03|3:49:47|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.72ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.64e+03|3:50:03|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.68ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.64e+03|3:50:20|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.74ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.64e+03|3:50:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.63ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.65e+03|3:50:52|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.67ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.65e+03|3:51:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.89ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.65e+03|3:51:26|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.34ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.65e+03|3:51:43|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.60ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.65e+03|3:52:00|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.61ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.66e+03|3:52:17|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.08ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.66e+03|3:52:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.70ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.66e+03|3:52:51|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.17ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.66e+03|3:53:07|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.01ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.66e+03|3:53:24|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.12ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.67e+03|3:53:41|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.69ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.67e+03|3:53:58|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.56ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.67e+03|3:54:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.72ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.67e+03|3:54:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.40ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.67e+03|3:54:47|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.11ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.68e+03|3:55:03|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.65ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.68e+03|3:55:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.89ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.68e+03|3:55:38|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.86ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.68e+03|3:55:53|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.49ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.68e+03|3:56:09|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.01ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.69e+03|3:56:26|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.18ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.69e+03|3:56:44|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.82ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.69e+03|3:57:00|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.38ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.69e+03|3:57:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.40ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.69e+03|3:57:32|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.86ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.70e+03|3:57:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.85ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.70e+03|3:58:06|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.65ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.70e+03|3:58:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.53ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.70e+03|3:58:38|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.60ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.70e+03|3:58:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.89ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.71e+03|3:59:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.34ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.71e+03|3:59:27|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.66ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.71e+03|3:59:43|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.32ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.71e+03|3:59:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.15ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:56 bilby INFO    : Checkpoint start\n",
      "00:56 bilby INFO    : Written checkpoint file outdir/lartillot_ptmc_d20_v0.01_resume.pickle\n",
      "00:56 bilby INFO    : Zero-temperature proposals:\n",
      "00:56 bilby INFO    : AdaptiveGaussianProposal(acceptance_ratio:0,n:1.3e+05,scale:1e-05,)\n",
      "00:56 bilby INFO    : DifferentialEvolutionProposal(acceptance_ratio:0,n:1.3e+05,)\n",
      "00:56 bilby INFO    : UniformProposal(acceptance_ratio:0,n:6e+03,)\n",
      "00:56 bilby INFO    : KDEProposal(acceptance_ratio:0,n:1.4e+05,trained:0,)\n",
      "00:56 bilby INFO    : FisherMatrixProposal(acceptance_ratio:0,n:1.4e+05,scale:1,)\n",
      "00:56 bilby INFO    : GMMProposal(acceptance_ratio:0,n:1.3e+05,trained:1,)\n",
      "00:56 bilby INFO    : Current taus={'x0': inf, 'x1': inf, 'x2': inf, 'x3': inf, 'x4': inf, 'x5': inf, 'x6': inf, 'x7': inf, 'x8': inf, 'x9': inf, 'x10': inf, 'x11': inf, 'x12': inf, 'x13': inf, 'x14': inf, 'x15': inf, 'x16': inf, 'x17': inf, 'x18': inf, 'x19': inf}\n",
      "00:56 bilby INFO    : Temperature swaps = 2237\n",
      "00:56 bilby INFO    : Temp:0<->1|beta=1|hot-samp=0|swap=0.00|conv=False|\n",
      "00:56 bilby INFO    : Temp:1<->2|beta=0.7169|hot-samp=6702|swap=1.00|conv=True|\n",
      "00:56 bilby INFO    : Temp:2<->3|beta=0.5139|hot-samp=6702|swap=0.00|conv=True|\n",
      "00:56 bilby INFO    : Temp:3<->4|beta=0.3684|hot-samp=0|swap=0.00|conv=False|\n",
      "00:56 bilby INFO    : Temp:4<->5|beta=0.2641|hot-samp=6702|swap=1.00|conv=True|\n",
      "00:56 bilby INFO    : Temp:5<->6|beta=0.1893|hot-samp=6702|swap=0.00|conv=True|\n",
      "00:56 bilby INFO    : Temp:6<->7|beta=0.1357|hot-samp=6702|swap=1.00|conv=True|\n",
      "00:56 bilby INFO    : Temp:7<->8|beta=0.09729|hot-samp=6702|swap=0.35|conv=True|\n",
      "00:56 bilby INFO    : Temp:8<->9|beta=0.06975|hot-samp=6702|swap=1.00|conv=True|\n",
      "00:56 bilby INFO    : Temp:9<->10|beta=0.05|hot-samp=6702|swap=-|conv=True|\n",
      "00:56 bilby INFO    : Creating diagnostic plots\n",
      "00:56 bilby INFO    : Checkpoint finished\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.71e+03|4:00:14|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.12ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.72e+03|4:00:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.25ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.72e+03|4:00:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.04ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.72e+03|4:01:04|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.79ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.72e+03|4:01:21|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.65ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.72e+03|4:01:37|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.68ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.73e+03|4:01:52|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.96ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.73e+03|4:02:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.90ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.73e+03|4:02:27|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.45ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.73e+03|4:02:43|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.46ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.73e+03|4:02:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.17ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.74e+03|4:03:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.16ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.74e+03|4:03:33|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.10ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "00:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.74e+03|4:03:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.53ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.74e+03|4:04:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.15ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.74e+03|4:04:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.92ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.75e+03|4:04:38|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.29ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.75e+03|4:04:55|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.54ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.75e+03|4:05:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.20ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.75e+03|4:05:28|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.88ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.75e+03|4:05:45|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.50ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.76e+03|4:06:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.04ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.76e+03|4:06:18|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.85ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.76e+03|4:06:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.33ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.76e+03|4:06:51|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.11ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.76e+03|4:07:07|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.93ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.77e+03|4:07:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.05ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.77e+03|4:07:41|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.33ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.77e+03|4:07:58|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.75ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.77e+03|4:08:13|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.81ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.77e+03|4:08:30|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.23ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.78e+03|4:08:45|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|76.90ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.78e+03|4:09:03|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.06ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.78e+03|4:09:21|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.24ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.78e+03|4:09:36|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|76.95ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.78e+03|4:09:53|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.87ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.79e+03|4:10:08|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.29ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.79e+03|4:10:26|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.47ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.79e+03|4:10:43|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.72ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.79e+03|4:10:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.86ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.79e+03|4:11:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.53ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.80e+03|4:11:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.56ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.80e+03|4:11:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.89ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.80e+03|4:12:06|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.66ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.80e+03|4:12:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|76.90ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.80e+03|4:12:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.36ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.81e+03|4:12:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|76.45ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.81e+03|4:13:13|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|94.23ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.81e+03|4:13:30|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.14ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.81e+03|4:13:46|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.55ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.81e+03|4:14:03|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.24ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.82e+03|4:14:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.06ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.82e+03|4:14:37|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.03ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.82e+03|4:14:55|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.35ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.82e+03|4:15:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.10ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.82e+03|4:15:28|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.65ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.83e+03|4:15:44|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.76ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.83e+03|4:16:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.98ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.83e+03|4:16:18|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.48ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.83e+03|4:16:34|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.52ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.83e+03|4:16:50|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.91ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.84e+03|4:17:06|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.64ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.84e+03|4:17:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.13ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.84e+03|4:17:41|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.81ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.84e+03|4:17:58|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.21ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.84e+03|4:18:14|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.70ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.85e+03|4:18:30|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.12ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.85e+03|4:18:47|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.40ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.85e+03|4:19:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.54ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.85e+03|4:19:21|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.55ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.85e+03|4:19:36|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.53ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.86e+03|4:19:53|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.11ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.86e+03|4:20:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.02ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.86e+03|4:20:28|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.27ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.86e+03|4:20:43|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.09ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.86e+03|4:20:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.77ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.87e+03|4:21:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.16ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.87e+03|4:21:32|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.14ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.87e+03|4:21:51|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|94.35ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.87e+03|4:22:07|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.63ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.87e+03|4:22:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.81ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.88e+03|4:22:40|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.45ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.88e+03|4:22:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.25ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.88e+03|4:23:14|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.60ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.88e+03|4:23:30|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.13ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.88e+03|4:23:46|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.74ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.89e+03|4:24:03|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.38ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.89e+03|4:24:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.86ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.89e+03|4:24:37|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.61ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.89e+03|4:24:53|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.40ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.89e+03|4:25:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.58ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.90e+03|4:25:26|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.51ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.90e+03|4:25:42|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.28ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.90e+03|4:26:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|91.13ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.90e+03|4:26:17|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.20ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.90e+03|4:26:34|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.76ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.91e+03|4:26:50|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.06ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.91e+03|4:27:06|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.18ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.91e+03|4:27:24|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.38ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.91e+03|4:27:41|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.36ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.91e+03|4:27:58|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.83ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.92e+03|4:28:14|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.01ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.92e+03|4:28:32|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.13ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.92e+03|4:28:51|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|95.01ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.92e+03|4:29:07|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.73ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.92e+03|4:29:24|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.61ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.93e+03|4:29:41|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.45ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.93e+03|4:29:58|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.73ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:26 bilby INFO    : Checkpoint start\n",
      "01:26 bilby INFO    : Written checkpoint file outdir/lartillot_ptmc_d20_v0.01_resume.pickle\n",
      "01:26 bilby INFO    : Zero-temperature proposals:\n",
      "01:26 bilby INFO    : AdaptiveGaussianProposal(acceptance_ratio:0,n:1.3e+05,scale:1e-05,)\n",
      "01:26 bilby INFO    : DifferentialEvolutionProposal(acceptance_ratio:0,n:1.3e+05,)\n",
      "01:26 bilby INFO    : UniformProposal(acceptance_ratio:0,n:6.2e+03,)\n",
      "01:26 bilby INFO    : KDEProposal(acceptance_ratio:0,n:1.4e+05,trained:0,)\n",
      "01:26 bilby INFO    : FisherMatrixProposal(acceptance_ratio:0,n:1.5e+05,scale:1,)\n",
      "01:26 bilby INFO    : GMMProposal(acceptance_ratio:0,n:1.4e+05,trained:1,)\n",
      "01:26 bilby INFO    : Current taus={'x0': inf, 'x1': inf, 'x2': inf, 'x3': inf, 'x4': inf, 'x5': inf, 'x6': inf, 'x7': inf, 'x8': inf, 'x9': inf, 'x10': inf, 'x11': inf, 'x12': inf, 'x13': inf, 'x14': inf, 'x15': inf, 'x16': inf, 'x17': inf, 'x18': inf, 'x19': inf}\n",
      "01:26 bilby INFO    : Temperature swaps = 2309\n",
      "01:26 bilby INFO    : Temp:0<->1|beta=1|hot-samp=0|swap=0.00|conv=False|\n",
      "01:26 bilby INFO    : Temp:1<->2|beta=0.7169|hot-samp=6918|swap=1.00|conv=True|\n",
      "01:26 bilby INFO    : Temp:2<->3|beta=0.5139|hot-samp=6918|swap=0.00|conv=True|\n",
      "01:26 bilby INFO    : Temp:3<->4|beta=0.3684|hot-samp=0|swap=0.00|conv=False|\n",
      "01:26 bilby INFO    : Temp:4<->5|beta=0.2641|hot-samp=6918|swap=1.00|conv=True|\n",
      "01:26 bilby INFO    : Temp:5<->6|beta=0.1893|hot-samp=6918|swap=0.00|conv=True|\n",
      "01:26 bilby INFO    : Temp:6<->7|beta=0.1357|hot-samp=6918|swap=1.00|conv=True|\n",
      "01:26 bilby INFO    : Temp:7<->8|beta=0.09729|hot-samp=6918|swap=0.35|conv=True|\n",
      "01:26 bilby INFO    : Temp:8<->9|beta=0.06975|hot-samp=6918|swap=1.00|conv=True|\n",
      "01:26 bilby INFO    : Temp:9<->10|beta=0.05|hot-samp=6918|swap=-|conv=True|\n",
      "01:26 bilby INFO    : Creating diagnostic plots\n",
      "01:26 bilby INFO    : Checkpoint finished\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.93e+03|4:30:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.30ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.93e+03|4:30:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.06ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.93e+03|4:30:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.82ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.94e+03|4:31:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.67ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.94e+03|4:31:21|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.82ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.94e+03|4:31:40|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|91.72ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.94e+03|4:31:56|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.78ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.94e+03|4:32:13|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.34ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.95e+03|4:32:29|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.58ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.95e+03|4:32:45|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.79ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.95e+03|4:33:03|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.36ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.95e+03|4:33:20|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.93ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.95e+03|4:33:37|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.81ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.96e+03|4:33:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.09ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.96e+03|4:34:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.57ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.96e+03|4:34:28|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.44ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.96e+03|4:34:45|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.92ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.96e+03|4:35:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.76ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.97e+03|4:35:17|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.75ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.97e+03|4:35:33|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.37ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.97e+03|4:35:51|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.42ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.97e+03|4:36:08|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.66ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.97e+03|4:36:24|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.93ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.98e+03|4:36:41|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.65ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.98e+03|4:36:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.77ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.98e+03|4:37:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.28ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.98e+03|4:37:32|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.77ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.98e+03|4:37:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.92ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.99e+03|4:38:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.64ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.99e+03|4:38:20|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.11ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.99e+03|4:38:38|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.54ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.99e+03|4:38:55|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.71ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "6.99e+03|4:39:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.64ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.00e+03|4:39:27|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.28ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.00e+03|4:39:44|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.41ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.00e+03|4:40:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.62ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.00e+03|4:40:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.39ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.00e+03|4:40:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.50ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.01e+03|4:40:52|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.20ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.01e+03|4:41:08|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.92ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.01e+03|4:41:26|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.83ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.01e+03|4:41:43|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.48ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.01e+03|4:41:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.16ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.02e+03|4:42:16|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.31ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.02e+03|4:42:32|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.46ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.02e+03|4:42:50|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.02ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.02e+03|4:43:08|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.80ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.02e+03|4:43:24|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.53ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.03e+03|4:43:40|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.33ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.03e+03|4:43:58|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.30ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.03e+03|4:44:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.13ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.03e+03|4:44:33|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.72ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.03e+03|4:44:50|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.07ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.04e+03|4:45:06|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.84ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.04e+03|4:45:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.33ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.04e+03|4:45:40|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.23ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.04e+03|4:45:58|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.94ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.04e+03|4:46:14|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.23ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.05e+03|4:46:30|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.99ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.05e+03|4:46:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.33ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.05e+03|4:47:04|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.63ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.05e+03|4:47:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.18ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.05e+03|4:47:38|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.31ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.06e+03|4:47:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.83ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.06e+03|4:48:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.58ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.06e+03|4:48:28|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.51ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.06e+03|4:48:46|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|92.45ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.06e+03|4:49:02|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.21ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.07e+03|4:49:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.08ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.07e+03|4:49:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.22ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.07e+03|4:49:51|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.08ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.07e+03|4:50:09|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.04ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.07e+03|4:50:25|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.99ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.08e+03|4:50:41|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.03ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.08e+03|4:50:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.11ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.08e+03|4:51:14|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.30ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.08e+03|4:51:33|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|94.37ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.08e+03|4:51:50|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.68ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.09e+03|4:52:06|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.01ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.09e+03|4:52:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.77ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.09e+03|4:52:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.95ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.09e+03|4:52:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.92ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.09e+03|4:53:13|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.45ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.10e+03|4:53:29|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.81ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.10e+03|4:53:46|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.98ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.10e+03|4:54:03|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.49ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.10e+03|4:54:20|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.82ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.10e+03|4:54:37|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.04ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.11e+03|4:54:53|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.50ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.11e+03|4:55:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.74ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.11e+03|4:55:27|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.14ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.11e+03|4:55:45|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.10ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.11e+03|4:56:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.48ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.12e+03|4:56:17|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.12ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.12e+03|4:56:34|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.04ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.12e+03|4:56:52|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.35ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.12e+03|4:57:09|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.70ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.12e+03|4:57:26|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.45ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.13e+03|4:57:42|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.64ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.13e+03|4:57:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.77ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.13e+03|4:58:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.14ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.13e+03|4:58:33|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.68ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.13e+03|4:58:50|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.23ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.14e+03|4:59:06|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.05ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.14e+03|4:59:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.41ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.14e+03|4:59:40|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.73ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.14e+03|4:59:58|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|91.27ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:56 bilby INFO    : Checkpoint start\n",
      "01:56 bilby INFO    : Written checkpoint file outdir/lartillot_ptmc_d20_v0.01_resume.pickle\n",
      "01:56 bilby INFO    : Zero-temperature proposals:\n",
      "01:56 bilby INFO    : AdaptiveGaussianProposal(acceptance_ratio:0,n:1.4e+05,scale:1e-05,)\n",
      "01:56 bilby INFO    : DifferentialEvolutionProposal(acceptance_ratio:0,n:1.4e+05,)\n",
      "01:56 bilby INFO    : UniformProposal(acceptance_ratio:0,n:6.4e+03,)\n",
      "01:56 bilby INFO    : KDEProposal(acceptance_ratio:0,n:1.5e+05,trained:0,)\n",
      "01:56 bilby INFO    : FisherMatrixProposal(acceptance_ratio:0,n:1.5e+05,scale:1,)\n",
      "01:56 bilby INFO    : GMMProposal(acceptance_ratio:0,n:1.4e+05,trained:1,)\n",
      "01:56 bilby INFO    : Current taus={'x0': inf, 'x1': inf, 'x2': inf, 'x3': inf, 'x4': inf, 'x5': inf, 'x6': inf, 'x7': inf, 'x8': inf, 'x9': inf, 'x10': inf, 'x11': inf, 'x12': inf, 'x13': inf, 'x14': inf, 'x15': inf, 'x16': inf, 'x17': inf, 'x18': inf, 'x19': inf}\n",
      "01:56 bilby INFO    : Temperature swaps = 2380\n",
      "01:56 bilby INFO    : Temp:0<->1|beta=1|hot-samp=0|swap=0.00|conv=False|\n",
      "01:56 bilby INFO    : Temp:1<->2|beta=0.7169|hot-samp=7132|swap=1.00|conv=True|\n",
      "01:56 bilby INFO    : Temp:2<->3|beta=0.5139|hot-samp=7132|swap=0.00|conv=True|\n",
      "01:56 bilby INFO    : Temp:3<->4|beta=0.3684|hot-samp=0|swap=0.00|conv=False|\n",
      "01:56 bilby INFO    : Temp:4<->5|beta=0.2641|hot-samp=7132|swap=1.00|conv=True|\n",
      "01:56 bilby INFO    : Temp:5<->6|beta=0.1893|hot-samp=7132|swap=0.00|conv=True|\n",
      "01:56 bilby INFO    : Temp:6<->7|beta=0.1357|hot-samp=7132|swap=1.00|conv=True|\n",
      "01:56 bilby INFO    : Temp:7<->8|beta=0.09729|hot-samp=7132|swap=0.35|conv=True|\n",
      "01:56 bilby INFO    : Temp:8<->9|beta=0.06975|hot-samp=7132|swap=1.00|conv=True|\n",
      "01:56 bilby INFO    : Temp:9<->10|beta=0.05|hot-samp=7132|swap=-|conv=True|\n",
      "01:56 bilby INFO    : Creating diagnostic plots\n",
      "01:56 bilby INFO    : Checkpoint finished\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.14e+03|5:00:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.45ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.15e+03|5:00:30|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.51ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.15e+03|5:00:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.10ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.15e+03|5:01:04|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.37ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.15e+03|5:01:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|93.54ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.15e+03|5:01:40|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.81ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.16e+03|5:01:56|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.37ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.16e+03|5:02:13|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.53ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.16e+03|5:02:30|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.55ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.16e+03|5:02:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.04ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.16e+03|5:03:06|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|91.28ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.17e+03|5:03:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.94ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "01:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.17e+03|5:03:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.80ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.17e+03|5:03:55|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.06ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.17e+03|5:04:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.97ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.17e+03|5:04:29|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.11ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.18e+03|5:04:45|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.59ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.18e+03|5:05:02|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.95ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.18e+03|5:05:17|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.59ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.18e+03|5:05:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.43ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.18e+03|5:05:53|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.35ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.19e+03|5:06:08|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.44ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.19e+03|5:06:25|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.70ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.19e+03|5:06:41|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.64ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.19e+03|5:06:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.74ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.19e+03|5:07:16|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.79ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.20e+03|5:07:32|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.97ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.20e+03|5:07:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.95ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.20e+03|5:08:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.83ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.20e+03|5:08:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.66ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.20e+03|5:08:40|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|91.36ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.21e+03|5:08:56|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.73ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.21e+03|5:09:13|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.23ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.21e+03|5:09:29|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.96ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.21e+03|5:09:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|92.76ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.21e+03|5:10:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.98ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.22e+03|5:10:20|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|78.99ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.22e+03|5:10:38|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.96ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.22e+03|5:10:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.13ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.22e+03|5:11:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.91ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.22e+03|5:11:29|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.26ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.23e+03|5:11:46|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.11ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.23e+03|5:12:03|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.81ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.23e+03|5:12:20|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.64ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.23e+03|5:12:37|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.28ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.23e+03|5:12:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.10ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.24e+03|5:13:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.32ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.24e+03|5:13:28|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.48ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.24e+03|5:13:45|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.85ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.24e+03|5:14:02|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.90ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.24e+03|5:14:20|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.23ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.25e+03|5:14:36|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.79ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.25e+03|5:14:52|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.86ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.25e+03|5:15:08|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.14ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.25e+03|5:15:25|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.91ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.25e+03|5:15:43|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.75ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.26e+03|5:15:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.05ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.26e+03|5:16:16|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.43ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.26e+03|5:16:32|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.59ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.26e+03|5:16:50|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.21ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.26e+03|5:17:07|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.75ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.27e+03|5:17:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.97ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.27e+03|5:17:40|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.95ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.27e+03|5:17:56|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.82ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.27e+03|5:18:13|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.37ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.27e+03|5:18:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|92.07ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.28e+03|5:18:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.23ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.28e+03|5:19:04|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.82ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.28e+03|5:19:20|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.26ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.28e+03|5:19:36|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.81ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.28e+03|5:19:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.67ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.29e+03|5:20:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.86ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.29e+03|5:20:27|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.33ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.29e+03|5:20:44|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.04ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.29e+03|5:21:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.06ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.29e+03|5:21:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|91.98ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.30e+03|5:21:37|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.61ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.30e+03|5:21:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.01ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.30e+03|5:22:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.20ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.30e+03|5:22:27|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.25ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.30e+03|5:22:44|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.11ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.31e+03|5:23:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.17ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.31e+03|5:23:18|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.68ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.31e+03|5:23:34|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.63ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.31e+03|5:23:52|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.94ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.31e+03|5:24:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.68ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.32e+03|5:24:27|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.89ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.32e+03|5:24:44|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.55ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.32e+03|5:25:00|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.57ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.32e+03|5:25:17|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.67ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.32e+03|5:25:34|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.73ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.33e+03|5:25:51|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.48ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.33e+03|5:26:08|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.04ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.33e+03|5:26:24|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.28ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.33e+03|5:26:41|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.13ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.33e+03|5:26:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.58ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.34e+03|5:27:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.64ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.34e+03|5:27:32|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.72ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.34e+03|5:27:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.02ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.34e+03|5:28:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.13ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.34e+03|5:28:24|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|95.23ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.35e+03|5:28:42|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.82ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.35e+03|5:28:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.00ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.35e+03|5:29:16|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.56ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.35e+03|5:29:33|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.21ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.35e+03|5:29:51|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|92.22ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby INFO    : Checkpoint start\n",
      "02:26 bilby INFO    : Written checkpoint file outdir/lartillot_ptmc_d20_v0.01_resume.pickle\n",
      "02:26 bilby INFO    : Zero-temperature proposals:\n",
      "02:26 bilby INFO    : AdaptiveGaussianProposal(acceptance_ratio:0,n:1.4e+05,scale:1e-05,)\n",
      "02:26 bilby INFO    : DifferentialEvolutionProposal(acceptance_ratio:0,n:1.4e+05,)\n",
      "02:26 bilby INFO    : UniformProposal(acceptance_ratio:0,n:6.6e+03,)\n",
      "02:26 bilby INFO    : KDEProposal(acceptance_ratio:0,n:1.5e+05,trained:0,)\n",
      "02:26 bilby INFO    : FisherMatrixProposal(acceptance_ratio:0,n:1.5e+05,scale:1,)\n",
      "02:26 bilby INFO    : GMMProposal(acceptance_ratio:0,n:1.4e+05,trained:1,)\n",
      "02:26 bilby INFO    : Current taus={'x0': inf, 'x1': inf, 'x2': inf, 'x3': inf, 'x4': inf, 'x5': inf, 'x6': inf, 'x7': inf, 'x8': inf, 'x9': inf, 'x10': inf, 'x11': inf, 'x12': inf, 'x13': inf, 'x14': inf, 'x15': inf, 'x16': inf, 'x17': inf, 'x18': inf, 'x19': inf}\n",
      "02:26 bilby INFO    : Temperature swaps = 2451\n",
      "02:26 bilby INFO    : Temp:0<->1|beta=1|hot-samp=0|swap=0.00|conv=False|\n",
      "02:26 bilby INFO    : Temp:1<->2|beta=0.7169|hot-samp=7345|swap=1.00|conv=True|\n",
      "02:26 bilby INFO    : Temp:2<->3|beta=0.5139|hot-samp=7345|swap=0.00|conv=True|\n",
      "02:26 bilby INFO    : Temp:3<->4|beta=0.3684|hot-samp=0|swap=0.00|conv=False|\n",
      "02:26 bilby INFO    : Temp:4<->5|beta=0.2641|hot-samp=7345|swap=1.00|conv=True|\n",
      "02:26 bilby INFO    : Temp:5<->6|beta=0.1893|hot-samp=7345|swap=0.00|conv=True|\n",
      "02:26 bilby INFO    : Temp:6<->7|beta=0.1357|hot-samp=7345|swap=1.00|conv=True|\n",
      "02:26 bilby INFO    : Temp:7<->8|beta=0.09729|hot-samp=7345|swap=0.35|conv=True|\n",
      "02:26 bilby INFO    : Temp:8<->9|beta=0.06975|hot-samp=7345|swap=1.00|conv=True|\n",
      "02:26 bilby INFO    : Temp:9<->10|beta=0.05|hot-samp=7345|swap=-|conv=True|\n",
      "02:26 bilby INFO    : Creating diagnostic plots\n",
      "02:26 bilby INFO    : Checkpoint finished\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.36e+03|5:30:08|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.34ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.36e+03|5:30:24|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.87ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.36e+03|5:30:41|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.56ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.36e+03|5:30:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.20ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.36e+03|5:31:15|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.02ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.37e+03|5:31:32|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.51ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.37e+03|5:31:47|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.50ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.37e+03|5:32:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.97ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.37e+03|5:32:21|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.23ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.37e+03|5:32:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|93.01ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.38e+03|5:32:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.14ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.38e+03|5:33:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.68ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.38e+03|5:33:29|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.01ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.38e+03|5:33:45|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.63ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.38e+03|5:34:03|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.35ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.39e+03|5:34:20|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.17ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.39e+03|5:34:36|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.86ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.39e+03|5:34:53|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.80ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.39e+03|5:35:09|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.99ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.39e+03|5:35:28|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|93.82ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.40e+03|5:35:45|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.47ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.40e+03|5:36:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.44ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.40e+03|5:36:18|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.69ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.40e+03|5:36:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.06ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.40e+03|5:36:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|94.89ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.41e+03|5:37:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.93ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.41e+03|5:37:27|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.97ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.41e+03|5:37:45|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.11ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.41e+03|5:38:02|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.77ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.41e+03|5:38:21|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|96.53ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.42e+03|5:38:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.18ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.42e+03|5:38:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.34ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.42e+03|5:39:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.79ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.42e+03|5:39:28|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.90ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:35 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.42e+03|5:39:46|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.75ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.43e+03|5:40:04|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.32ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.43e+03|5:40:20|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.62ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:36 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.43e+03|5:40:37|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.89ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.43e+03|5:40:53|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.92ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.43e+03|5:41:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.05ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.44e+03|5:41:21|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|105.54ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:37 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.44e+03|5:41:38|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.94ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.44e+03|5:41:55|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.67ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.44e+03|5:42:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.83ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.44e+03|5:42:28|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.09ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:38 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.44e+03|5:42:46|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|91.20ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.45e+03|5:43:04|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.86ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.45e+03|5:43:20|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.46ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:39 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.45e+03|5:43:37|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.89ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.45e+03|5:43:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.91ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.46e+03|5:44:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.73ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.46e+03|5:44:29|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.65ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:40 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.46e+03|5:44:45|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.21ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.46e+03|5:45:03|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.80ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.46e+03|5:45:20|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.20ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:41 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.46e+03|5:45:38|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.83ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.47e+03|5:45:56|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.93ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.47e+03|5:46:13|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.18ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.47e+03|5:46:30|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.14ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:42 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.47e+03|5:46:46|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.49ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.48e+03|5:47:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|91.99ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.48e+03|5:47:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.16ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:43 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.48e+03|5:47:38|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|77.96ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.48e+03|5:47:55|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.36ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.48e+03|5:48:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.69ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.48e+03|5:48:30|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.33ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:44 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.49e+03|5:48:47|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.13ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.49e+03|5:49:04|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.82ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.49e+03|5:49:20|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.74ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:45 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.49e+03|5:49:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|75.77ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.50e+03|5:49:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|91.60ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.50e+03|5:50:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|93.29ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.50e+03|5:50:29|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.19ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:46 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.50e+03|5:50:46|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.35ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.50e+03|5:51:02|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.32ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.50e+03|5:51:20|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.20ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:47 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.51e+03|5:51:38|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.06ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.51e+03|5:51:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.76ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.51e+03|5:52:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.49ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.51e+03|5:52:29|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.86ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:48 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.52e+03|5:52:47|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|92.17ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.52e+03|5:53:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.21ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.52e+03|5:53:21|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.75ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:49 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.52e+03|5:53:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.84ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.52e+03|5:53:55|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.68ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.52e+03|5:54:13|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|92.12ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.53e+03|5:54:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.18ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:50 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.53e+03|5:54:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.99ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.53e+03|5:55:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.53ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.53e+03|5:55:21|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.88ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:51 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.54e+03|5:55:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.41ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.54e+03|5:55:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.51ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.54e+03|5:56:14|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.55ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.54e+03|5:56:30|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.92ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:52 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.54e+03|5:56:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.02ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.54e+03|5:57:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.82ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.55e+03|5:57:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.33ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:53 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.55e+03|5:57:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.29ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.55e+03|5:57:56|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.23ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.55e+03|5:58:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.14ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.56e+03|5:58:30|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.46ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:54 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.56e+03|5:58:48|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|92.05ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.56e+03|5:59:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.74ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.56e+03|5:59:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.47ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:55 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.56e+03|5:59:40|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.67ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.56e+03|5:59:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.85ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:56 bilby INFO    : Checkpoint start\n",
      "02:56 bilby INFO    : Written checkpoint file outdir/lartillot_ptmc_d20_v0.01_resume.pickle\n",
      "02:56 bilby INFO    : Zero-temperature proposals:\n",
      "02:56 bilby INFO    : AdaptiveGaussianProposal(acceptance_ratio:0,n:1.4e+05,scale:1e-05,)\n",
      "02:56 bilby INFO    : DifferentialEvolutionProposal(acceptance_ratio:0,n:1.4e+05,)\n",
      "02:56 bilby INFO    : UniformProposal(acceptance_ratio:0,n:6.7e+03,)\n",
      "02:56 bilby INFO    : KDEProposal(acceptance_ratio:0,n:1.5e+05,trained:0,)\n",
      "02:56 bilby INFO    : FisherMatrixProposal(acceptance_ratio:0,n:1.6e+05,scale:1,)\n",
      "02:56 bilby INFO    : GMMProposal(acceptance_ratio:0,n:1.5e+05,trained:1,)\n",
      "02:56 bilby INFO    : Current taus={'x0': inf, 'x1': inf, 'x2': inf, 'x3': inf, 'x4': inf, 'x5': inf, 'x6': inf, 'x7': inf, 'x8': inf, 'x9': inf, 'x10': inf, 'x11': inf, 'x12': inf, 'x13': inf, 'x14': inf, 'x15': inf, 'x16': inf, 'x17': inf, 'x18': inf, 'x19': inf}\n",
      "02:56 bilby INFO    : Temperature swaps = 2521\n",
      "02:56 bilby INFO    : Temp:0<->1|beta=1|hot-samp=0|swap=0.00|conv=False|\n",
      "02:56 bilby INFO    : Temp:1<->2|beta=0.7169|hot-samp=7555|swap=1.00|conv=True|\n",
      "02:56 bilby INFO    : Temp:2<->3|beta=0.5139|hot-samp=7555|swap=0.00|conv=True|\n",
      "02:56 bilby INFO    : Temp:3<->4|beta=0.3684|hot-samp=0|swap=0.00|conv=False|\n",
      "02:56 bilby INFO    : Temp:4<->5|beta=0.2641|hot-samp=7555|swap=1.00|conv=True|\n",
      "02:56 bilby INFO    : Temp:5<->6|beta=0.1893|hot-samp=7555|swap=0.00|conv=True|\n",
      "02:56 bilby INFO    : Temp:6<->7|beta=0.1357|hot-samp=7555|swap=1.00|conv=True|\n",
      "02:56 bilby INFO    : Temp:7<->8|beta=0.09729|hot-samp=7555|swap=0.35|conv=True|\n",
      "02:56 bilby INFO    : Temp:8<->9|beta=0.06975|hot-samp=7555|swap=1.00|conv=True|\n",
      "02:56 bilby INFO    : Temp:9<->10|beta=0.05|hot-samp=7555|swap=-|conv=True|\n",
      "02:56 bilby INFO    : Creating diagnostic plots\n",
      "02:56 bilby INFO    : Checkpoint finished\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.57e+03|6:00:16|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.62ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:56 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.57e+03|6:00:32|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.04ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.57e+03|6:00:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.72ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.57e+03|6:01:06|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.69ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.58e+03|6:01:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.18ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:57 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.58e+03|6:01:41|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.92ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.58e+03|6:01:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.06ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.58e+03|6:02:14|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.40ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:58 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.58e+03|6:02:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.59ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.58e+03|6:02:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.16ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.59e+03|6:03:08|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|93.41ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.59e+03|6:03:24|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.99ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "02:59 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.59e+03|6:03:42|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.52ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.59e+03|6:03:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.76ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.60e+03|6:04:16|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.24ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:00 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.60e+03|6:04:34|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|91.49ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.60e+03|6:04:51|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.53ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.60e+03|6:05:08|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.64ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.60e+03|6:05:25|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.09ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:01 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.60e+03|6:05:42|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.63ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.61e+03|6:06:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|96.90ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.61e+03|6:06:18|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.87ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:02 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.61e+03|6:06:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.35ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.61e+03|6:06:52|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.43ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.62e+03|6:07:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.08ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.62e+03|6:07:28|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.01ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:03 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.62e+03|6:07:45|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.47ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.62e+03|6:08:02|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.00ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.62e+03|6:08:18|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.63ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:04 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.62e+03|6:08:34|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.16ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.63e+03|6:08:52|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.70ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.63e+03|6:09:09|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.40ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.63e+03|6:09:26|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.45ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:05 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.63e+03|6:09:43|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.85ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.64e+03|6:10:00|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.96ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.64e+03|6:10:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|94.58ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:06 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.64e+03|6:10:36|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.46ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.64e+03|6:10:53|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.41ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.64e+03|6:11:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.04ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.64e+03|6:11:26|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.12ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:07 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.65e+03|6:11:45|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|92.30ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.65e+03|6:12:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.09ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 8-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.65e+03|6:12:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.41ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:08 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.65e+03|6:12:35|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.45ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.66e+03|6:12:53|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.64ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.66e+03|6:13:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|91.77ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:09 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.66e+03|6:13:28|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.37ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:09 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.66e+03|6:13:44|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.65ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.66e+03|6:14:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.44ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.66e+03|6:14:18|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.27ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:10 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.67e+03|6:14:37|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|92.87ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.67e+03|6:14:55|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.52ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.67e+03|6:15:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.16ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:11 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.67e+03|6:15:28|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.40ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:11 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.68e+03|6:15:45|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.85ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.68e+03|6:16:03|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.40ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.68e+03|6:16:21|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.97ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:12 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.68e+03|6:16:37|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.99ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.68e+03|6:16:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.19ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.68e+03|6:17:10|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.55ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:13 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.69e+03|6:17:29|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|93.97ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.69e+03|6:17:47|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.77ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.69e+03|6:18:04|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.88ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.69e+03|6:18:21|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.96ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:14 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.70e+03|6:18:37|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.85ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.70e+03|6:18:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.65ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.70e+03|6:19:12|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.91ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:15 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.70e+03|6:19:28|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|79.53ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:15 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.70e+03|6:19:46|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.35ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.70e+03|6:20:02|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.39ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.71e+03|6:20:20|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|91.80ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:16 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.71e+03|6:20:38|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.30ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.71e+03|6:20:55|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.66ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.71e+03|6:21:13|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.68ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:17 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.72e+03|6:21:30|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.21ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.72e+03|6:21:50|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|97.30ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.72e+03|6:22:09|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|96.78ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.72e+03|6:22:26|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.45ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:18 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.72e+03|6:22:43|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.43ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.72e+03|6:22:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|80.74ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.73e+03|6:23:09|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|101.03ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.73e+03|6:23:27|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.69ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:19 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.73e+03|6:23:44|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.69ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.73e+03|6:24:02|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.69ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.73e+03|6:24:20|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.27ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:20 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.74e+03|6:24:37|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.65ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.74e+03|6:24:56|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|94.97ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.74e+03|6:25:13|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.37ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:21 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.74e+03|6:25:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.20ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.74e+03|6:25:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.66ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.75e+03|6:26:05|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.14ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.75e+03|6:26:23|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.93ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:22 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.75e+03|6:26:40|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.23ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.75e+03|6:26:58|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.81ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.75e+03|6:27:16|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.06ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:23 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.76e+03|6:27:33|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.81ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.76e+03|6:27:52|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|95.16ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.76e+03|6:28:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|92.70ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:24 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.76e+03|6:28:27|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.05ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:24 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.76e+03|6:28:46|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.56ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.77e+03|6:29:04|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|89.49ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.77e+03|6:29:22|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.47ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:25 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.77e+03|6:29:39|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|88.59ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.77e+03|6:29:56|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|82.37ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:26 bilby INFO    : Checkpoint start\n",
      "03:26 bilby INFO    : Written checkpoint file outdir/lartillot_ptmc_d20_v0.01_resume.pickle\n",
      "03:26 bilby INFO    : Zero-temperature proposals:\n",
      "03:26 bilby INFO    : AdaptiveGaussianProposal(acceptance_ratio:0,n:1.5e+05,scale:1e-05,)\n",
      "03:26 bilby INFO    : DifferentialEvolutionProposal(acceptance_ratio:0,n:1.5e+05,)\n",
      "03:26 bilby INFO    : UniformProposal(acceptance_ratio:0,n:6.9e+03,)\n",
      "03:26 bilby INFO    : KDEProposal(acceptance_ratio:0,n:1.6e+05,trained:0,)\n",
      "03:26 bilby INFO    : FisherMatrixProposal(acceptance_ratio:0,n:1.6e+05,scale:1,)\n",
      "03:26 bilby INFO    : GMMProposal(acceptance_ratio:0,n:1.5e+05,trained:1,)\n",
      "03:26 bilby INFO    : Current taus={'x0': inf, 'x1': inf, 'x2': inf, 'x3': inf, 'x4': inf, 'x5': inf, 'x6': inf, 'x7': inf, 'x8': inf, 'x9': inf, 'x10': inf, 'x11': inf, 'x12': inf, 'x13': inf, 'x14': inf, 'x15': inf, 'x16': inf, 'x17': inf, 'x18': inf, 'x19': inf}\n",
      "03:26 bilby INFO    : Temperature swaps = 2590\n",
      "03:26 bilby INFO    : Temp:0<->1|beta=1|hot-samp=0|swap=0.00|conv=False|\n",
      "03:26 bilby INFO    : Temp:1<->2|beta=0.7169|hot-samp=7762|swap=1.00|conv=True|\n",
      "03:26 bilby INFO    : Temp:2<->3|beta=0.5139|hot-samp=7762|swap=0.00|conv=True|\n",
      "03:26 bilby INFO    : Temp:3<->4|beta=0.3684|hot-samp=0|swap=0.00|conv=False|\n",
      "03:26 bilby INFO    : Temp:4<->5|beta=0.2641|hot-samp=7762|swap=1.00|conv=True|\n",
      "03:26 bilby INFO    : Temp:5<->6|beta=0.1893|hot-samp=7762|swap=0.00|conv=True|\n",
      "03:26 bilby INFO    : Temp:6<->7|beta=0.1357|hot-samp=7762|swap=1.00|conv=True|\n",
      "03:26 bilby INFO    : Temp:7<->8|beta=0.09729|hot-samp=7762|swap=0.35|conv=True|\n",
      "03:26 bilby INFO    : Temp:8<->9|beta=0.06975|hot-samp=7762|swap=1.00|conv=True|\n",
      "03:26 bilby INFO    : Temp:9<->10|beta=0.05|hot-samp=7762|swap=-|conv=True|\n",
      "03:26 bilby INFO    : Creating diagnostic plots\n",
      "03:26 bilby INFO    : Checkpoint finished\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.77e+03|6:30:13|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|86.37ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:26 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.78e+03|6:30:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|87.67ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.78e+03|6:30:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|92.07ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.78e+03|6:31:07|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|91.33ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:27 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.78e+03|6:31:24|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|81.89ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.78e+03|6:31:42|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|90.24ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.79e+03|6:31:59|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|84.47ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.79e+03|6:32:18|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|99.11ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:28 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.79e+03|6:32:37|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|92.53ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.79e+03|6:32:54|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|85.84ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.79e+03|6:33:13|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|94.52ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:29 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.80e+03|6:33:30|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|83.66ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.80e+03|6:33:41|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|110.63ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.80e+03|6:33:51|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|102.07ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.80e+03|6:34:01|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|101.94ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.80e+03|6:34:11|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|101.21ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:30 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.80e+03|6:34:30|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|92.47ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.80e+03|6:34:49|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|97.60ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.81e+03|6:35:09|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|99.37ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.81e+03|6:35:20|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|108.24ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:31 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.81e+03|6:35:33|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|126.65ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.81e+03|6:35:44|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|114.59ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.81e+03|6:35:57|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|126.92ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.81e+03|6:36:08|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|107.49ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.81e+03|6:36:19|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|117.68ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:32 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 7-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.81e+03|6:36:31|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|121.20ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.81e+03|6:36:43|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|119.60ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.82e+03|6:36:55|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|111.47ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.82e+03|6:37:06|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|110.74ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.82e+03|6:37:18|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|123.69ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:33 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.82e+03|6:37:32|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|138.52ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 6-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "7.82e+03|6:37:44|9.97e+02(AD)|t=inf|n=0|a=0.00|e=0.0e+00%|124.47ms/ev|maxl=-662.57|ETF=-\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error singular matrix\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 5-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 4-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 3-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n",
      "03:34 bilby WARNING : Failed to refit chain due to error 2-th leading minor of the array is not positive definite\n"
     ]
    }
   ],
   "source": [
    "v, dim = 0.01, 20\n",
    "results_20d = dict()\n",
    "results_20d[\"True\"] = true_lnz(v, dim)\n",
    "results_20d[\"Nested Sampling\"] = nested_sampling_lnz(v, dim)\n",
    "results_20d[\"Parallel Tempering\"] = parallel_tempering_lnz(v, dim)\n",
    "results_20d[\"FI\"] = fi_lnz(v, dim)"
   ],
   "metadata": {
    "collapsed": false,
    "pycharm": {
     "is_executing": true
    }
   }
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "outputs": [],
   "source": [
    "print_result_dict(results_20d, dim, v)"
   ],
   "metadata": {
    "collapsed": false,
    "pycharm": {
     "is_executing": true
    }
   }
  },
  {
   "cell_type": "markdown",
   "source": [
    "## 100D Case"
   ],
   "metadata": {
    "collapsed": false
   }
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "outputs": [],
   "source": [
    "v, dim = 0.01, 100\n",
    "results_100d = dict()\n",
    "results_100d[\"True\"] = true_lnz(v, dim)\n",
    "results_100d[\"Nested Sampling\"] = nested_sampling_lnz(v, dim)\n",
    "results_100d[\"Parallel Tempering\"] = parallel_tempering_lnz(v, dim)\n",
    "results_100d[\"FI\"] = fi_lnz(v, dim)"
   ],
   "metadata": {
    "collapsed": false,
    "pycharm": {
     "is_executing": true
    }
   }
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "outputs": [],
   "source": [
    "print_result_dict(results_100d, dim, v)"
   ],
   "metadata": {
    "collapsed": false,
    "pycharm": {
     "is_executing": true
    }
   }
  },
  {
   "cell_type": "markdown",
   "source": [
    "## Comparison Plot"
   ],
   "metadata": {
    "collapsed": false
   }
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "outputs": [],
   "source": [
    "import matplotlib.pyplot as plt\n",
    "\n"
   ],
   "metadata": {
    "collapsed": false
   }
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3 (ipykernel)",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.8.10"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 4
}
